;	PROF1D
;
; PURPOSE:

;	Cette procedure trace une image unidimensionnelle
;	(intensite et/ou polarisation)
; CATEGORY:
;	NRH1 profils
;
; CALLING SEQUENCE:
;	 PROF1D,Images, Unit 
;
; INPUTS:
;	IMAGES Tableau d'images 2dim(espace,temps) ou 3dim(espace,temps,I:V)
;		voir lec1d
;	UNIT	Unite logique associee au tableau
;
; KEYWORD PARAMETERS:
;	INTENSITE trace du parametre I
;	POLAR	  trace du parametre V
;	HEURES	  Tableau de chaine de caracteres [Heure debut,Heure de fin]
;			format de l'heure "hh:mn:ss:ccc"
;		  Heure de trace = Heure de debut
;	CANAUX	  tableau contenant [Canal de debut, Canal de fin]
;			format: valeurs entieres
;	LASER	  Sortie dans un fichier Poscript
;	NOERASE	  Superposition des images
;	WIN	  Numeros des fenetres (a voir)
;
; OUTPUTS:
;	Trace d'une image
;
; COMMON BLOCKS:
;	NRH1_GLOBAL
;
; MODIFICATION HISTORY: (bonmartin@obspm.fr)
;	13/11/98) Adapte du logiciel XHELIO
;-*******************************************************************



PRO prof1d,tabl_X, lun, laser=Laser $
             ,Intensite=intensite, Polar=Polar, WIN=win, NOERASE=noerase $
             ,HEURE=heure, CANAUX=canaux 

;
;* ---------------------------- *
;*	Test de la syntaxe      *    revoir !!!!!!
;* ---------------------------- *
;
IF N_PARAMS() LE 1 THEN BEGIN
   print,$
    'Syntaxe: prof1d, Tableau a tracer, Numero d unite logique'$
   , '          [,LASER=laser' $ 
   , '            ,Intensite=intensite,Polar=Polar, WIN=win,NOERASE=noerase,' $
   , '            ,BORD=bord,HEURE=heure, CANAUX=canaux,' $
   , '		]'
; 
ENDIF

;
;* ------------------------------------------- *
;*	Declaration des variables globales     *
;* ------------------------------------------- *
;            

COMMON NRH1_GLOBAL,nomfich,FichInfo      

;
; Memorisation des informations principales
; sur le fichier
;
file = fichinfo(lun)
heuredeb = file.Heurdeb
heurefin = file.HeurFin
dt = file.paspix(1)	; intervalle de temps
dx = file.paspix(0)	; intervalle de canaux
cdeb = file.valorg(0)
cfin = cdeb + (file.nbpix(0)-1)*dx

;
; ---------------------------------- 
;	Transformation de l'heure     
;         en milliseconde            
;- ---------------------------------- 
;

IF NOT KEYWORD_SET(heure) THEN h = heuredeb ELSE h = HMS(heure)

;---------------------------------------------
; Test sur la conformite de l'heure specifiee
;---------------------------------------------

IF (h LT heuredeb OR h GT heurefin) THEN h = heuredeb

;-------------------------------------------
; Test sur la conformite des canaux specifies
;-------------------------------------------

IF NOT KEYWORD_SET(canaux) THEN BEGIN
	cnldeb=cdeb
	cnlfin=cfin
ENDIF ELSE BEGIN
	cnldeb=canaux(0)
	cnlfin=canaux(1)
ENDELSE
IF (cnldeb GE cnlfin) THEN BEGIN
	print,'CANAL DEB > OR = THAN CANAL FIN'
	RETURN
ENDIF
IF(cnldeb GT cdeb AND cnldeb LT cfin) THEN cnldeb=cdeb+FIX((cnldeb-cdeb)/dx)*dx
IF(cnlfin GT cdeb AND cnlfin LT cfin) THEN cnlfin=cfin+FIX((cnlfin-cfin)/dx)*dx
canaux = [cnldeb, cnlfin]

xcoor = cdeb + findgen(file.nbpix(0))*dx	; Tableau d'Abscisses: canaux

num = indice(heuredeb,h,dt, heurelue)
heure = MSH(heurelue)
h = heurelue
 
;---------------------------------------------------------------
;  CHARGEMENT DES INFORMATIONS A AFFICHER
;---------------------------------------------------------------

freq=motcle(lun,'FREQ')
label=motcle(lun,'LABEL')
type=motcle(lun,'TYPE')
xtitle = 'Canal /' + string(label)
ytitle = 'Amplitude /' + string(freq)
subtitle = string(fichinfo(lun).date) + '   ' + heure

;-------------------------------------
; Test de la specification d'un numero
; de fenetre
;-------------------------------------
IF (NOT KEYWORD_SET(win)) THEN BEGIN
  win = intarr(2)
  win(0) = 1
  win(1) = 2
ENDIF


  ;formatage de la fenetre de visualisation

   ;* ----------------------------------------------- *
   ;*	Prise en compte du priphrique de sortie     *
   ;* ----------------------------------------------- *

IF KEYWORD_SET(laser) THEN postscript,/ON	; **** voir diff. LASER / POSTSCRIPT


     ;------------------------------------------------
     ;    Affichage de la brillance
     ;------------------------------------------------  
     
IF (!P.MULTI(1) NE 0) THEN Taille=0.4 ELSE Taille=0.8

IF KEYWORD_SET(intensite) THEN BEGIN

	LoadIntens,Tabl_x,imagex,num,Fichinfo,lun
	j=!P.color

	IF(KEYWORD_SET(polar) EQ 1) THEN ytitle = 'I & V - ' + ytitle $
			ELSE ytitle = 'I - ' + ytitle

	maximage = MAX(imagex, MIN = minimage)
	IF(KEYWORD_SET(polar)) THEN minimage = -maximage
	space = 0.1*(maximage-minimage)
	yrange = [minimage-space, maximage+space]

	PLOT,xcoor,imagex, $
		XTITLE = xtitle, YTITLE = ytitle, SUBTITLE = subtitle, $
		xstyle=1 ,ystyle=1, XRANGE=canaux, YRANGE=yrange,$
		YMARGIN=[10,2], NOERASE=noerase, COLOR=j, CHARSIZE=Taille

ENDIF
	
     ;------------------------------------------------
     ;    Affichage de la polarisation
     ;------------------------------------------------  
IF KEYWORD_SET(polar) THEN BEGIN
       LoadPolar, Tabl_x,imageX,num,FichInfo,lun,ok

       j=!P.color


	IF (ok EQ 1) THEN BEGIN

		IF(NOT KEYWORD_SET(intensite)) THEN BEGIN
			ytitle = 'V - ' + ytitle
			PLOT, xcoor, imagex,$
			XTITLE = xtitle, YTITLE = ytitle, SUBTITLE = subtitle,$
			xstyle=1, NOERASE=noerase, COLOR=j, $
			CHARSIZE = Taille, XRANGE = canaux
		ENDIF ELSE BEGIN
			OPLOT, xcoor, imagex, line = 2
		ENDELSE

	ENDIF
ENDIF

IF KEYWORD_SET(laser) THEN BEGIN
    postscript,/OFF
ENDIF
 
END



