
;+ ***********************************************************************
; NAME:
;	FOPEN_STD_SOHO
;
; PURPOSE:
;	Cette procedure ouvre un fichier SOHO et de fichiers FITS au standard
;	SOHO
;
; CATEGORY:
;	Fichiers
;
; CALLING SEQUENCE:
;	FOPEN_STD_SOHO, File, Str_fic
;
; INPUTS:
;	FILE	Nom du fichier
;	
; KEYWORD PARAMETERS:
;	Rien
;
; OUTPUTS:
;	STR_FIC	Structure de description du fichier (NRH_STR_INFIC). Cette
;	structure doit etre declaree avant l'appel
;
; COMMON BLOCKS:
;	Rien
;
; PROCEDURE:
;	Le STANDARD SOHO implique que 
;		le fichier ne contient pas d'extensions
;		il y a une seule image (NAXIS = 2)
;	Les mots cles traites sont: DATE-OBS, TIME-OBS, NAXIS1, NAXIS2
;		EXPTIME, CRPIX1, CRPIX2, SOLAR_R
;	Si ces mots cles ne sont pas presents les informations sont incorrectes
;	sauf pour CRPIX1, CRPIX2, SOLAR_R. Si un de ces mots cles n'existe pas
;	l'image est visualisee et il y a demande de determiner le soleil 
;	optique
;		
;
; EXAMPLE:
;	Please provide a simple example here
;
; MODIFICATION HISTORY:
;	Ecrit par: J Bonmartin (obspm.fr) le: 24/08/98
;-*******************************************************************

PRO FOPEN_STD_SOHO, File, Str_inf2d

	H = HEADFITS( File)

		Str_inf2d.Content = 'STD'
		Str_inf2d.Freq = 0.0

		Str_inf2d.date= FXPAR(h,'DATE-OBS')
		str_inf2d.nim = 1
		Str_inf2d.hd = FXPAR(h, 'TIME-OBS')
		Str_inf2d.hf = Str_inf2d.hd
		Str_inf2d.npx = FXPAR (h, 'NAXIS1')
		Str_inf2d.npy = FXPAR (h,'NAXIS2')

	  	Str_inf2d.Tscan = Fxpar(h, 'EXPTIME')
		Str_inf2d.Xcen = FXPAR(h, 'CRPIX1')
			IF !ERR LT 0 THEN BEGIN 
				IMAGE = MRDFITS(file)
			Optic_circ, IMAGE, Xcen, Ycen, Ray
			STR_Inf2d.Xcen=Xcen&Str_inf2d.Ycen=Ycen
			Str_inf2d.ray=ray
			RETURN & END

		Str_inf2d.Ycen = FXPAR(h, 'CRPIX2')
			IF !ERR LT 0 THEN BEGIN 
				IMAGE = MRDFITS(file)
			Optic_circ, IMAGE, Xcen, Ycen, Ray
			STR_Inf2d.Xcen=Xcen&Str_inf2d.Ycen=Ycen
			Str_inf2d.ray=ray
			RETURN & END

		Str_inf2d.Ray = FXPAR(h, 'SOLAR_R')
			IF !ERR LT 0 THEN BEGIN 
				IMAGE = MRDFITS(file)
			Optic_circ, IMAGE, Xcen, Ycen, Ray
			STR_Inf2d.Xcen=Xcen&Str_inf2d.Ycen=Ycen
			Str_inf2d.ray=ray
			RETURN & END

END

