
;+ ***********************************************************************
; NAME:
;	NRH2_PROJECT2D
;
; PURPOSE:
;	Cette procedure calcule la projection des images d'un fichier NRH2
;	sur une direction donnee
;
; CATEGORY:
;	NRH2 project
;
; CALLING SEQUENCE:
;	 NRH2_PROJECT2D, File, Str_inf, Lim, Angle, Data, Time, Strc
;
; INPUTS:
;	FILE	Nom du fichier
;	STR_INF	Structure NRH_STR_INFIC
;	LIM	Structure NRH_STR_LIM
;	ANGLE	Angle de la direction sur la quelle est effectuee la 
;		projection
;	
; KEYWORD PARAMETERS:
;	STOKES	Parametre de Stokes 0 intensite 1 parametre V
;
; OUTPUTS:
;	DATA	tableau resultat
;	TIME	Tableau de temps
;	STRC	Structure NRH_STR_INFIC, avec valeurs resultantes
;
; PROCEDURE:
;	Cette procedure calcule la rotation des images puis somme les points
;	de chaque colonne de l'image apres rotation
;
; EXAMPLE:
;	Please provide a simple example here
;
; MODIFICATION HISTORY:
;	Ecrit par: J Bonmartin (obspm.fr) le 09/07/99
;-*******************************************************************

PRO NRH2_PROJECT2D, File, Str_inf, Lim, Angle, Data, Time, Strc, $
	STOKES = stokes

IF NOT KEYWORD_SET(STOKES) THEN Stokes=0

	IDEB = TIME_IND_NRH(File, Lim.Hd)
	IFIN = TIME_IND_NRH(File, Lim.Hf)

STRC = Str_inf
Strc.Hd= Lim.Hd
Strc.Hf= Lim.Hf

DATA = FLTARR(Ifin-Ideb+1, Lim.Xf-Lim.Xd+1)
TIME = STRARR(Ifin-Ideb+1)

	IL=0
	FOR I=Ideb, Ifin DO BEGIN
		RD_NRH2I, File, '', Str_inf, Donnee, Str_im, INDIC=I, $
			STOKES=Stokes

		Image= NRH_ROTIM(Donnee,Angle,Xc,Yc,XCEN=Str_inf.Xcen,$
					YCEN=Str_inf.Ycen)
		ID=0
		FOR Ipoint= Lim.Xd, Lim.Xf DO BEGIN
			Data[Il,Id] = TOTAL (Image[Ipoint,Lim.Yd:Lim.Yf])
			Id = Id+1
		ENDFOR
		Time[Il] = Str_im.time
		IL = IL + 1
	ENDFOR

Strc.Xcen = Xc
Strc.Ycen = Yc

END