PRO RH_CLOSE_HEADER, iunit, dirdsmf, nbfreq, ch,	$
		     itd, itf, numrec, npew, 		$
		     date, imstd, imstf, mmin, mmax
;+ ***********************************************************************
; NAME:
;	RH_CLOSE_HEADER
; PURPOSE:
;	Cette procedure ferme les fichiers FITS d'images 2D 
;	 et met a jour les headers. 
; CATEGORY:
;	Traitement de fichiers NRH
; CALLING SEQUENCE: 
;	RH_CLOSE_HEADER,iunit, dirdsmf, nbfreq, ch,	$
;		     itd, itf, numrec, npew, 		$
;		     date, imstd, imstf, mmin, mmax
;
; INPUTS:

;	nbfreq : nb de frequences 
;	date      : date 
;	Npew    : nb de points en EW et en NS
;	Imstd    : heure de debut  (ms)
;	Imstf    : heure de fin    (ms)
;	CH	: pour la selection des frequences 
;		  = ch(10) 'Y' ou 'N'

; OUTPUTS:
;	IUNIT	: tableau des numeros d'unite d'ecriture
;	DIRDSMF : tableau des noms precedes du chemin des fichiers FITS
; MODIFICATION HISTORY:
;	Ecrit par A. Bouteille
; 26 janvier 2010 : appel de RH_MOD_HEADER avec le mot cle NBRE_ENRGT
;                   pour modifier naxis2 avec le nb reel d images ecrites 
;-**************************************************************************  
    formatdate = "(i2.2,'/',i2.2,'/',i4.4," + $
                 "'  debut        fin          records  points')"
    print,date, format=formatdate
    for nf=0,nbfreq-1 do begin
        if ch(nf) eq 'Y' then begin
;           close,iunit(nf)
            fxbfinish, iunit(nf), errmsg=errmsg
            print,nf+1,itd(*,nf),itf(*,nf),numrec(nf),npew,npew, $
             format='("  2D:",i2,2x,2(2(i2.2,":"),i2.2,".",i2.2,3x),i8,i5,i5)'
        endif
    endfor
; mise a jour du header sur disque
    for nf = 0, nbfreq-1  do begin
        if (ch(nf) eq 'Y') then RH_MOD_HEADER, $
            dirdsmf(nf), date, $
             imstd(nf), imstf(nf), mmin(nf), mmax(nf), $
             NBRE_ENRGT = numrec(nf)
    endfor
end

