

PRO RH_FIT_CUBIC,  $
	ident=ident,  i_stop,  i_c,  i_sys_lin,	$ ; entree (parametres).
	i_phi_lin,				$ ; ------------------
	nh1,  nh2,  af,	 			$ ; entree (donnees).
	i_amp_phas, tcon, tnul, n_tnul,		$ ; entree, entree ou sortie
	fit				  	  ; sortie
; Usages :
;   - Determiner un fit 1D ou 2D, central ou decale, sur une TF : partie reelle
;	partie imaginaire, module ou phase. Le mot-cle ident sert a identifer 
;	les differents cas 1D, et evite de modifier la liste des arguments du 
;	cas 2D.
;	Pour un fit central, on suppose que le modele de visibilite observe
;	ne comporte pas de "marche d'Heavyside" le long de l'axe u, c'est a 
;	dire que cette marche, si elle existe, est d'origine insttrumentale.
;	=> on detecte cette marche dans le calcul du fit, mais on ne l'inclut
;	   pas dans le modele. Elle est donc attribuee aux phases instrumenta-
;	   les.
;   - A partir du 31 oct 00 determiner une base lisse locale au voisinage
;	d'une source compacte sur une base de soleil calme. Ce cas est reconnu
;	par ident=-1 (la valeur 0 passee par keyword ne met pas a 1 le keyword_
;	set, ce qui est bien emmerdant et j'ai mis un moment a le trouver). 
;     Dans le cas du fit d'une base (appel par SOUSTRAC_BASE), afin d'eviter 
;	de modifier la liste des arguments, nh1 et nh2 sont les coordonnees xm
;	et ym, comptees a partir du coin inferieur gauche de l'image definie 
;	sur sur np*np points du maximum d'image.
;     Le fit est contraint sur un zone centree autour de(xm, ym) mais en exclu-
;	ant le voisinage immediat de la source compacte. i_c est pris non nul 
;	en entree (1 ou 2) pour faire un fit du 3eme degre general.
;     Cet usage est destine a ameliorer l'ecretage dans la recherche de la 
;	base, en permettant un meilleur ajustement de la largeur des bandes 
;	d'ecretage EW et NS.

; Procedure de lancement pour essais : T_CUBIC.PRO

; print, 'coucou (passage dans RH_FIT_CUBIC)'

    i_s = i_stop 
;   if(i_stop eq 1) then stop		; eviter de s'arreter a tous les appels

; Notations :
;  i_amp_phas	pour discerner entre le fit d'un module (i_amp_phas = 1), pour
;		  lequel on determine le domaine de contrainte et le fit d'une
;		  phase (i_amp_phas = 2), pour lequel on utilise le domaine de
;		  contrainte precedemment determine pour le module. Les varia-
;		  bles  
;  tcon, tnul	domaines de contrainte ou rejete (entree ou sortie).	 
;  n_tnul 	nbre d'elements de tnul.

; PRO FIT_CUBIC,  af, n1, ident=ident,	 $	; entree. Avant 13 juin 2000.
;	     A, B, C, D, E, F,  fit		; sortie
	; le fit etait centre et n1 etait le nbre d'harmoniques (l'actuel nh2).

; USAGE FIT DE TF :
; Le tableau af en entree est un tableau reel 1D ou 2D pouvant etre :
;   - partie reelle ou partie imaginaire, ou
;   - module ou phase 
;   d'une TF centree (en milieu de tableau) de la source corrigee de sa posi-
;   tion (la TF est donc quasi-reelle aux bas harm). Ce n'est plus un ensemble
;   d'harmoniques bruts observes. 
;   Les valeurs de la TF ont ete bien mises a leur place dans le plan (u, v),
;   quelle que soit l'antenne maitresse (avec E0 ce sont des harm impairs).
; Le tableau "fit" en sortie est 1D ou 2D comme le tableau en entree. Il est 
;   plus petit que af. L'immersion est faite en aval dans les procedures appe-
;   lantes FIT_TF_1D et FIT_TF_2D.
; Le fit est contraint par les points ou les donnees sont significatives :
;   - pour le fit d'un module les donnees doivent etre > valeur significative 
;       minimale calculee dans RH_FIT_CUBIC.  On produit en sortie les ta-
;	bleaux tcon et tnul des indices des valeurs acceptees et rejetees.
;   - pour le fit d'une phase (toujours fait apres le fit du module) on utilise
;	en entree les tableaux tcon et tnul produits en sortie au passage pre-
;	cedent de FIT_CUBIC pour le module.

; Cas 2D :
;   - si i_c=0  RH_FIT_CUBIC est utilise pour la modelisation de la phase. Le 
;	domaine de contrainte est (depuis le 10 dec 04) la moitie superieure du
;	pave central carre de cote 2*nh2 (s'etendant sur 2*nh2+1 harmoniques) :
;		af(np/2-nh2 : np/2+nh2, np/2-nh2 : np/2+nh2)
;	Ceci permet de faire un fit impair avec une "marche d'Heavyside" le 
;	  long le l'axe u. On a en effet constat'e qu'une telle marche pouvait 
;	  exister (cas du soleil du 27 aug 02 a 9:13). On determine donc une 
;	  constante dans le fit, mais on ne l'inclut pas dans le modele de 
;	  source car elle ne peut qu'avoir une origine instrumentale.
;	On peut au choix faire un fit comprenant ou non le yerme lineaire (pa-
;	  rametre i_phi_lin).
;
;   - si i_c=1  le domaine de fit est un pave decal'e sur l'axe u, carre et de
;       cote impair. En posant :
;	  	n0 = (nh1 + nh2) / 2	abscisse     du centre du pave
;		nc = (nh2 - nh1) / 2	1/2 longueur du cote   du pave
;	  le domaine de fit est :	   
;			af(np/2+n0-nc : np/2+n0-nc, np/2-nc : np/2+nc) 
;       le fit est une cubique generale
;   - si i_c=2  idem avec decalage sur l'axe v, et le domaine de fit est :
;			af(np/2-nc : np/2+nc, np/2+n0-nc : np/2+n0-nc)
;     le fit est une cubique generale
;
;   On calcule le fit :
;	   fit = A  +  B*x  +  C*y  +  D*x^2  +  E*x*y    +  F*y^2    +
;			  	       G*x^3  +  H*x^2*y  +  K*x*y^2  +  L*y^3
;       (i et j son sautes par precaution dans les noms).
;     x et y sont les indices comptees a partir du centre du tableau. Le fit 
;     est calcule a partir des points superieurs a une certaine fraction de la
;     moyenne des pts entourant le point central (definition du tableau tcon).
;     Ceci pour fitter de facon realiste la visibilite dans le cas ou la sour-
;     ce servant a la calibration est complexe (on s'attend que la TF puisse
;     varier fortement sur le domaine de contrainte).
;   Ancien :
;	    fit = A*x  +  B*y    +  C*x^3    +  D*x^2*y  +  E*x*y^2  +  F*y^3
;
; Les noms des coefficients sont les memes dans tous les fits (1D, 2D, i_c=0, 
;   1 ou 2), mais seuls les coefficients concernes sont non nuls.
;
; Cas 1D (voir aussi commentaires a l'appel de RH_FIT_CUBIC dans FIT_TF_1D):
; Si le tableau en entree est a une dimension le fit l'est aussi. 
;   - si i_c=0  le domaine de contrainte est reduit aux frequences >0 :
;		af(np/2 : np/2+nh2)
;   - si i_c=1 ou 2  avec les memes n0 et nc le domaine de contrainte 1D est
;		af(np/2+n0-nc : np/2+n0-nc) 
;  Pour i_c=0  A, B, G  sont calcules, les autres sont pris nuls.
;  Pour i_c>0  A, B, D, G  -------------------------------------
; Le mot-cle ident sert a identifer les differents cas 1D, et evite de modifier
;   la liste des arguments du cas 2D.
; Domaine de definition du fit produit en sortie :
;   - si i_c = 0 le fit est defini sur [-nh2, nh2]
;   - si i_c > 0 --------------------- [ nh1, nh2]

; Modifications
; 00 mar 10  ajout du cas 1D
;    jun 13  ajout du cas 1D non impair pour modeliser loin de l'origine.
;    jul  3  introduction d'une fonction de ponderation pour tenter d'ameliorer
;		les fit 2D decale sur l'axe u, en ponderant davantage les 
;		points sur l'axe u. Dans ce cas en effet on mesure la TF sur
;		l'axe au dela du pave, ce qui n'est pas le cas pour l'axe v au
;		dela de 23.
;    oct 31  determination de la base locale sous une source compacte (2D seu-
;		lement).
;    nov 10  on discerne entre le fit d'un module (i_amp_phas = 1) Pour lequel
;		on determine le domaine de contrainte et le fit d'une phase
;		(i_amp_phas = 2), pour lequel on utilise le domaine de contrain
;		te precedemment determine pour le module. Les variables tcon, 
;		tnul et n_tnul sont en entree ou sortie.
;    nov 20  ajout d'un terme constant a la modelisation 1D de la phase des
;		modeles centraux, jusque la strictement impaire. Le domaine de 
;		contrainte est reduit aux frequences positives, mais apres 
;		calcul le fit est etendu par symetrie impaire au domaine 
;		(-nh2, nh2) pour etre le meme que celui du fit du module par 
;		RH_FIT_QUARTIC.
;    nov 21  cas 1D : on fitte la phase d'un modele central avec la somme d'une
;		constante et d'un terme du 3eme degre, sans terme du 1er degre.
;	      Ceci a cause de l'extreme sensibilite du fit aux dephasages des
;		antennes pour les bas harmoniques : apres l'ajout du terme
;		constant dans le fit le 20 nov il n'y a plus rien qui force le
;		modele a etre nul et avoir une pente de phase faible pres de 
;		l'origine, alors que cela devrait etre le cas puisque le bary-
;		centre de l'image a ete place a l'origine. 
;	      Cette meme sensibilite a la phase des bas harmoniques peut aussi
;		produire une ordonnee a l'origine non nulle meme quand l'anten-
;		ne maitresse (unique en 1D) n'est pas dephasee.
;	      On espere que supprimer le terme lineaire "contraindra" mieux 
;		le modele. De fait : grosse amelioration !!
;	      A 2D il n'y a pas cet effet puisqu'il y a plusieurs antennes
;		maitresses et dans le cas des modeles centraux on n'introduit 
;		pas de terme constant et on garde les termes lineaires (pour 
;		l'instant).
;    nov 27   possibilite de fit 2D avec les termes cubiques seuls (sans termes
;		lineaires)
; 01 mar 26   remplacement de CRAMER par RH_LINEAR_SVD, considere comme plus 
;		fiable. Fait aussi dans RH_FIT_QUADRIC et RH_FIT_CUBIC.
;    mai 31   introduction de i_sys_lin (transmis depuis CALIBRATION) pour
;		choisir la methode de resolution des systemes limeaires (1 Cra-
;		mer, 2 LU, 3 SVD)
;    jun 13  dans le cas 1D : sous-ponderation des points aux extremites du
;		domaine de contrainte (pour eviter une trop grande influence 
;		de ces points quand ils sont entaches d'erreur ou bruit, vu
;		qu'il n'y a pas de contrainte plus loin). Cette modif est faite
;		en pensant aux modeles de visibilite 1D, dont on souhaite 
;		qu'ils soient aussi bons que possible pres de l'origine pour en
;		deduire le gain complexe des antennes maitresses.
;    dec 17  retablissement (en option depuis CALIBRATION) du terme line-
;		aire dans la modelisation des phases des  modeles centraux.
; 04 dec 10  le fit central 2D est contraint par le 1/2 plan uv superieur seul
;		et comporte un terme constant (donc en fait une "marche d'Hea-
;		vyside" le long de l'axe u).

    chsiz = 1.3

    taille = size(af)
    n_dim = taille(0)
    npx  = taille(1)		; dimension 1D ou 1ere dimension 2D.
    n2 = npx / 2

    if(n_dim eq 0) then begin
	print, 'RH_FIT_CUBIC : le tableau entree a la dimension 0'
	x = toto		; plantage volontaire pour avoir le detail des
				;   appels.
	stop
    endif
    if (n_dim eq 1) then goto, a1
    if (n_dim eq 2) then goto, a2
    if(n_dim gt 2) then begin
	print, 'RH_FIT_CUBIC : le tableau entree a une dimension > 2'
	stop
    endif


; CAS A UNE DIMENSION
a1: J_M = 0

; Definition du domaine de contrainte :
	; - numero n0 de l'harmonique situe en son centre,
	; - 1/2 extension nc (le fit est contraint sur 2*nc+1 harmoniques).

;  avant le 20 nov 00 :
;   if (i_c eq 0) then begin		; nh1 ignor'e, nh2 est l'ancien nh.
;	n0 = 0				; origine de la TF.
;	nc = nh2
;   endif
;   if ((i_c eq 1) or (i_c eq 2)) then begin	; domaine de fit : (nh1, nh2)
;	n0 = (nh1 + nh2) / 2			; abscisse du centre.
;	nc = (nh2 - nh1) / 2			; 1/2 extension
;   endif

;  apres la modif du 20 nov 00,  n0 et nc ne servent plus qu'aux cas decentres.
    n0 = (nh1 + nh2) / 2			; abscisse du centre.
    nc = (nh2 - nh1) / 2			; 1/2 extension


; Generation d'une fonction connue, d'allure impaire.
    imp0 = 0
    if (imp0 eq 1) then begin
	np = 128
	B0 = 0.50 / nc		; variation sur le domaine fe fit.
	G0 = 0.30 / nc^3	
	vx = findgen(2*nc+1) - n1
	af_c = B0*vx  +  G0*vx^3
	af = fltarr(np)
	af(np/2-nc, np/2-nc) = af_c
	plot, af_c, xstyle=1, title='fonction fabriquee sur zone de fit'
	stop
    endif
; Fin de controle  

; Creation du sous-tableau recouvrant le domaine de contrainte choisi (le ta-
	;   bleau reellement utilise pour contraindre le fit, avec des points
	;   d'amplitude suffisante, est plus reduit et defini plus bas). 
	; Le domaine est toujours d'un seul tenant: 
	; - i_c = 0  reduit aux frequences positives pour permettre l'ajout
	;	d'un terme constant aux termes impairs dans le cas du fit d'une
	;	phase (modif du 20 nov 00).
	; - i_c = 1 ou 2 idem et le decalage est assez grand (on fitte autour
	;	autour de 16 (EW) ou 18 (NS) pour qu'il soit alors entierement
	;	du cote des frequences positives.
    if (i_c eq 0) then begin		; modeles centraux
	fc = af(n2 : n2+nh2)		;   contrainte sur freq >0 seules
    endif
    if (i_c gt 0) then begin		; modeles decales
	fc = af(n2+n0-nc : n2+n0+nc)
    endif
;   fc = af(n2-n1 : n2+n1)	; avant le 13 juin 2000. n1 etait l'actuel nh2
    	; fc est un fltarr(2*nc+1) ,centr'e sur af(n2+n0).

; Controle du sous-tableau recouvrant le domaine de contrainte a-priori
    icon = 0
    if ((icon eq 1) and (i_stop eq 1)) then begin
	print, 'FIT_CUBIC : controle du tableau de donnees'
	print, 'n2+n0-nc,  n2+n0+nc', n2+n0-nc,  n2+n0+nc
	help, fc
	window, 0	& wset, 0
	plot, fc, xstyle=1
	xyouts, 0.5, 0.97, /normal, alignment=0.5, $
		'Tableau 1D de donnees dans fit_cubic'
	stop
    endif
; Fin de controle  

;  Calcul d'une moyenne de l'amplitude des harmoniques (fit d'un module).
	; Rappel des valeurs de ident dans les cas fit de TF :  
	;  1 pour  E1     avec E1  a H16   (harmoniques impairs nuls), 
	;  2 pour  E0     avec E1  a H16   (harmoniques   pairs nuls), 
	;  3 pour  NS0_ns avec E1  a H16   (indice = rang des harmoniques),  
	;  4 pour  NS0_ew avec NS0 a NS45  (indice = rang des harmoniques),  
	;  5 pour  NS0_ns avec NS7 a NS45  (indice = rang des harmoniques et 
	;				    les harm 1 a 6 sont nuls), 
	;  6 pour  NS8    avec NS0 a NS17  (indice n'est pas le rang des harm).
	; Les commentaires de fin de ligne ne sont valables que dans le cas 
	;   i_c=0. Autrement les "rangs" des harm doivent etre compris par rap-
	;   port au point milieu de l'intervalle de contrainte.
    if (i_amp_phas eq 1) then begin			; cas d'un module
	if ((ident eq 1) or (ident eq 3)) then begin	; harm EW pairs.
	    if (imp0 eq 0) then begin			; vestige mise au point
		fc_moy = total(abs(fc(nc-4:nc+4))) / 4	; moy sur -4 -2   2   4
	    endif
	    if (imp0 eq 1) then begin			; vestige mise au point
		fc_moy = total(abs(fc(nc-2:nc+2))) / 4	; pour fonction connue
	    endif
	endif 
	if (ident eq 2) then begin			; harm EW impairs.
	    fc_moy = total(abs(fc(nc-5:nc+5))) / 6	; sur -5 -3 -1  1 3 5
	endif
	if (ident eq 4) then begin			; harm NS avec NS0_ew.
	    fc_moy = total(abs(fc(nc-4:nc+4))) / 8	; sur -4 a 4, 0 exclus
	endif
	if (ident eq 5) then begin			; harm NS avec NS0_ns.
	    if (i_c eq 0) then  begin
;		fc_moy = total(abs(fc(nc+6-9:nc+6+9))) / 6   ; ?? moy sur 7 a 9
		fc_moy = total(abs(fc(nc+7:nc+9))) / 3    ; moy sur 7 a 9
	    endif
	    if (i_c eq 2) then  begin
		fc_moy = total(abs(fc(nc-4:nc+4))) / 8  ; moy sur voisins de nc
		    ; faute trouvee le 25 sep 00 : /3 au lieu de /8  . fc_moy 
		    ; etait trop grand. Le fit ne s'appuyait que sur les points
		    ; vraiment les plus eleves et etait curieusement infidele 
		    ; pour les autres.
	    endif
	endif
 	if (ident eq 6) then begin			; harm NS avec NS0_ew.
	    fc_moy = total(abs(fc(nc-4:nc+4))) / 8	; sur -4 a 4, 0 exclus
	endif 
	frac = 0.3		; fraction min moyenne pour um harm acceptable.
	fc_min = frac * fc_moy	; seuil de val absolue pour participer au fit.

	tcon   = where(abs(fc) gt fc_min)	; adresses des pts ou 
						;   abs(fc) > fc_min.
	tnul = where(abs(fc) lt fc_min, n_tnul)
    endif	; fin calcul domaine de contrainte dans le cas d'un module
    if (i_amp_phas eq 2) then begin
	    ; Il faut reduire tcon et tnul fournis en entree s'ils ont ete
	    ;   fournis par FIT_QUARTIC pour un fit central (i_c=0), car ils 
	    ;   correspondent au domaine de contrainte (-nh2, nh2), alors 
	    ;   qu'ici on contraint seulement sur (0, nh2). On rappelle que
	    ;   tcon et tnul fournis contiennent des indices >0, avec zero
	    ;   a l'extremite gauche du tableau de contrainte fc dans la proce-
	    ;   dure de fit du module.
	if (i_c eq 0) then begin
		; On utilise le fait que si un harm >0 est selctionne (ou non)
		;   pour contraindre le fit, son oppose l'est aussi (ou non).
	    n_el_con = n_elements(tcon)		; toujours pair
	    n_el_nul = n_elements(tnul)		; toujours impair
	    tcon = tcon(n_el_con/2 : n_el_con-1) - nh2
	    tnul = tnul(n_el_nul/2 : n_el_nul-1) - nh2
	endif
	icon = 0
	if ((icon eq 1) and (i_s eq 1)) then begin
	    print, 'RH_FIT_CUBIC :'
	    print, '   tableau de contrainte'
	    print, tcon
	    print, '   tableau de nullite'
	    print, tnul
	    stop
	endif
    endif

; Calcul des abscisses des points contraignant le fit. On prend :
	; - modeles centraux : abscisses a partir de l'origine par commodite.
	; - ------- decales  : ------------------ du milieu de l'intervalle de
	;	contrainte pour eviter de manipuler des nombres trop grands
	;	dans les sommes de puissances.
	; Rappel : n0 = (nh1 + nh2) / 2	est l'abscisse du centre du domaine de
	;		 contrainte.
	;	   nc = (nh2 - nh1) / 2	est sa 1/2 extension.
	; Rappel : les indices tcon du domaine de contrainte sont comptes :
	;	   - a partir de l'origine des TF dans le cas central
	;	   - a partir de la borne inferieure de l'intervalle de con-
	;		trainte dans le cas decale.
    if (i_c eq 0) then   xx = tcon	; xx compte a partir de l'origine.
    if (i_c gt 0) then   xx = tcon - nc	; ----------------- du milieu de l'in-
					;		tervalle de contrainte.

; Controle de xx 
    icon = 0
    if ((i_s eq 1) and (icon eq 1)) then begin
	print, 'RH_FIT_CUBIC : controle de xx  .   tcon ='
	window, 0	& wset, 0
	plot, fc, xstyle=1
	xyouts, -.5, 0.97, /normal, alignment=0.5, $
		'domaine de contrainte (y compris pts faibles)'
	print, tcon
	if (i_c eq 0) then begin
	    print, $
		'Tableau xx des abscisses (>0) utilisees, avec zero a ' + $
		'l origine des frequences'
	endif
	if (i_c ne 0) then begin
	    print, $
		'Tableau xx des abscisses utilisees, avec zero au milieu ' + $
		'de l intervalle de contrainte'
	endif
	print, xx
	stop
    endif
    ; conclusion: OK
; Fin de controle  

; Definition de la fonction de ponderation
	; Les fits 1D peuvent etre tres influences par les erreurs sur les
	; points a la limite du domaine de contrainte (surtout dans le cas du 
	; fit d'une phase). L'effet est particulierement desastreux pour le
	; recalage des antennes NS18 a NS23, qu'on ne peut recaler que par rap-
	; port a NS0, et qui penalise le recalage de NS45. Dans l'espoir de 
	; reduire cet effet on utilise une fonction de ponderation qui decroit
	; pres de la limite de l'intervalle de contrainte. Les essais faits le
	; 13 nov 00 montrent que ca ne change que peu (il semble qu'en fait
	; la fonction de ponderation etait definie mais non utilisee).
	;
	; Le 14 juin 01 on corrige ca pour tenter d'ameliorer le fit des phases
	;   des harm EW de E1 et E0.
;  Avant le 14 juin 01 
;    if (i_c eq 0) then  w = replicate(1., nh2 +1)
;    if (i_c gt 0) then  w = replicate(1., 2*nc+1)
;    i_pond = 0			; 0 sans ponderation,  1 avec (mise au point).
;    if (i_pond eq 0) then goto, a5
;    if (i_c eq 0) then  n_max = nh2
;    if (i_c gt 0) then  n_max = 2*nc
;    w0   = 0.15 & w1 = 0.30  & w2 = 0.45  & w3 = 0.60  & w4 = 0.75  & w5 = 0.9
;    w(0) = w0		& w(n_max    ) = w0
;    w(1) = w1		& w(n_max - 1) = w1
;    w(2) = w2		& w(n_max - 2) = w2
;    w(3) = w3		& w(n_max - 3) = w3
;    w(4) = w4		& w(n_max - 4) = w4
;    w(5) = w5		& w(n_max - 5) = w5
;a5: J_M = 0
;    wt = w(tcon)	; fin de la sequence avant 14 juin 01.
;  Apres le 14 juin 01 (la fonction de ponderation est directement definie sur
	; le domaine de contrainte
    wt = replicate(1., n_elements(xx))
    i_pond = 1			; 0 sans ponderation,  1 avec .
    if (i_pond eq 0) then goto, a6
    n_max = n_elements(xx) - 1
;   w0   = 0.15	 & w1 = 0.30  & w2 = 0.45  & w3 = 0.60  & w4 = 0.75  & w5 = 0.9
    w0   = 0.40	 & w1 = 0.80  & w2 = 1.00  & w3 = 1.00  & w4 = 1.00  & w5 = 1.0
    wt(0) = w0		& wt(n_max    ) = w0
    wt(1) = w1		& wt(n_max - 1) = w1
    wt(2) = w2		& wt(n_max - 2) = w2
    wt(3) = w3		& wt(n_max - 3) = w3
;   wt(4) = w4		& wt(n_max - 4) = w4
;   wt(5) = w5		& wt(n_max - 5) = w5
a6: J_M = 0
; Visualisation de la fonction de ponderation
    icon = 0
    if((icon eq 1) and (i_stop eq 1)) then begin
	window, 0	& wset, 0
	plot, wt
	xyouts, /normal, 0.5, 0.97, alignment=0.5, $
	    'ponderation des pts contraints dans fit_cubic'
	print, 'RH_FIT_CUBIC :'
	print, '    nbre d elements de wt :', n_elements(wt)
	help, wt, xx
	stop
    endif

; Calcul de sommes (termes de la matrice) en double precision
    xx  = double(xx)		&  fc  = double(fc)
    Sx0 = total (wt      )		; = n_elements(xx)  sans ponderation.
    Sx1 = total (wt * xx  )
    Sx2 = total (wt * xx^2)
    Sx3 = total (wt * xx^3)
    Sx4 = total (wt * xx^4)
    Sx5 = total (wt * xx^5)
    Sx6 = total (wt * xx^6)

; Calcul des sommes du vecteur membre de droite
    Sfx0 = total (wt * fc(tcon)      )
    Sfx1 = total (wt * fc(tcon) * xx  )
    Sfx2 = total (wt * fc(tcon) * xx^2)
    Sfx3 = total (wt * fc(tcon) * xx^3)

    xx = float(xx)    & fc = float(fc)	   ; restauration en simple precision.
    
    
; Resolution du systeme lineaire. On garde les memes notations qu'en 2D.
	;  fit = A  +  B*x  +  C*y  +  D*x^2  +  E*x*y    +  F*y^2    +
	;			       G*x^3  +  H*x^2*y  +  K*x*y^2  +  L*y^3
    if (i_c eq 0) then begin		; fit central impair.
;     avant le 20 nov 00 (fit purement impair sans terme constant A) :
;	mat =  [[Sx2  ,   Sx4 ], $
;		[Sx4  ,   Sx6 ]]
;	vec =   [Sfx1 ,   Sfx3]
;	res = CRAMER(mat, vec)
;	B = float ( res(0) )
;	G = float ( res(1) )
;	A = 0   & C = 0   & D = 0   & E = 0  & F = 0  & H = 0  & K = 0  & L = 0
;     apres le 20 nov 00 (avec terme constant A) :
	if (i_phi_lin eq 0) then begin		
		; avec termes deg 0 et 3, sans termes deg 1 et 2.
	    mat =  [[Sx0,   Sx3], $
		    [Sx3,   Sx6]]
	    vec =  [Sfx0,  Sfx3] 
	    if (i_sys_lin eq 1) then  res = CRAMER       (mat, vec)
	    if (i_sys_lin eq 2) then  res = RH_LINEAR_LU (mat, vec, i_stop)
	    if (i_sys_lin eq 3) then  res = RH_LINEAR_SVD(mat, vec, i_stop)
	    A = float ( res(0) )
	    G = float ( res(1) )
	    B = 0  & C = 0   & D = 0   & E = 0   & F = 0   & H = 0   & K = 0
	    L = 0
	endif
	if (i_phi_lin eq 1) then begin
		; avec terme deg 0, 1, 3, sans terme deg 2.
	    mat =  [[Sx0,   Sx1,   Sx3], $
		    [Sx1,   Sx2,   Sx4], $
		    [Sx3,   Sx4,   Sx6]]
	    vec =  [Sfx0,  Sfx1,  Sfx3] 
	    if (i_sys_lin eq 1) then  res = CRAMER       (mat, vec)
	    if (i_sys_lin eq 2) then  res = RH_LINEAR_LU (mat, vec, i_stop)
	    if (i_sys_lin eq 3) then  res = RH_LINEAR_SVD(mat, vec, i_stop)
	    A = float ( res(0) )
	    B = float ( res(1) )
	    G = float ( res(2) )
	    C = 0   & D = 0   & E = 0   & F = 0   & H = 0   & K = 0   & L = 0
	endif
    endif
    if ((i_c eq 1) or (i_c eq 2)) then begin  ; fit general (termes 0, 1, 2, 3)
	mat =  [[Sx0,   Sx1,   Sx2,   Sx3], $
		[Sx1,   Sx2,   Sx3,   Sx4], $
		[Sx2,   Sx3,   Sx4,   Sx5], $
		[Sx3,   Sx4,   Sx5,   Sx6]]
	vec =  [Sfx0,  Sfx1,  Sfx2,  Sfx3] 
	if (i_sys_lin eq 1) then  res = CRAMER       (mat, vec)
	if (i_sys_lin eq 2) then  res = RH_LINEAR_LU (mat, vec, i_stop)
	if (i_sys_lin eq 3) then  res = RH_LINEAR_SVD(mat, vec, i_stop)
	A = float ( res(0) )
	B = float ( res(1) )
	D = float ( res(2) )
	G = float ( res(3) )
	C = 0   & E = 0   & F = 0   & H = 0   & K = 0   & L = 0
    endif

; Controle du fit et comparaison avec la fonction connue
    icon = 0
    if ((icon eq 1) and (i_stop eq 1)) then begin
      ; renormalisation pour comparaison avec la simulation
	B2=A*nc  &  G2=C*nc^3
	print, 'Valeurs comparees des coeff entres et calcules:'
	ch = '        B             G'
	print, ch
	print, B0,  G0
	print, B2 , G2 
	stop
    endif
    ; Conclusion: valeurs identiques, OK.
; Fin de controle  
    
;  Construction du vecteur vx des abscisses du domaine de contrainte, de meme 
	; dimension que le tableau fc defini plus haut.
    if (i_c eq 0) then  vx = lindgen(nh2  + 1)
    if (i_c gt 0) then  vx = lindgen(2*nc + 1)  -  nc

; Calcul de la fonction fit sur tout le domaine du fit (pts non fittes inclus).
    fit    = A  +  B*vx  +  D*vx^2  +  G*vx^3
	; rappel : le produit d'un float (B) par un long (vx) est un float.
    diff_1 = fc(tcon) - fit(tcon)			; diff_1 tableau 1D.
    res    = sqrt ( total(diff_1^2) / total(fc^2) )	; residu relatif.
    fit2   = fit 
    if(n_tnul gt 0) then  fit2(tnul) = 0	
	; pour comparer avec les donnees reelles.
    
    diff_2 = fc - fit2		; pour tracer.

; Controle du fit et visualisation sur le domaine de contrainte.
    icon = 0
    if ((icon eq 1) and (i_stop eq 1)) then begin
	if (i_phi_lin eq 0) then ch_print = 'sans terme lineaire)'
	if (i_phi_lin eq 1) then ch_print = 'avec terme lineaire)'
	print, 'RH_FIT_CUBIC : arret comparaison fonction de contrainte ' + $
		'et fit ', '                ' + ch_print
;     Visualisation de la partie de af a fitter et des fits.
	if (nh2 gt nh1) then absc = nh1 + indgen(nh2 - nh1 + 1)
	if (nh2 lt nh1) then absc = nh2 + indgen(nh1 - nh2 + 1)
	window, 0	&	wset, 0
	plot,  absc, fc,  xstyle=1
	oplot, absc, fit, linestyle=2
	xyouts, 0.5, 0.97, /normal, alignment=0.5, $
		'fonction entree (domaine de contrainte), fit - -'
;     Trace axe des abscisses
	x_a = [-nh2, nh2]	& y_a = [0, 0]
	oplot, x_a, y_a, linestyle=1
;	window, 1	&	wset, 1
;	plot, absc, fit, xstyle=1
;	xyouts, 0.5, 0.97, /normal, alignment=0.5, $
;		'fonction fit (domaine de contrainte)'
	window, 1	&	wset, 1
	plot, absc, diff_2, xstyle=1
	xyouts, 0.5, 0.97, /normal, alignment=0.5, $
		'fonction - fit (domaine de contrainte)' 
	print, '    residu relatif:', res
	print, ' '
;     Coefficients du fit et valeur des termes des differents ordres
	print, '    Fit  =  A  +  B*vx  +  D*vx^2  +  G*vx^3'
	ch_format = $
	    "('    A =', f8.5, '   B =', f8.5, '   D =', f8.5, '   G =', f8.5)"
	print, format=ch_format, A, B, D, G
	xm = max(abs(vx))
	Bm = B * xm    & Dm = D * xm^2    & Gm = G * xm^3
	print, '  Valeurs max des termes du fit :'
	ch_format = $
	    "('    B*xm =', f8.5, '  D*xm^2 =', f8.5,'  G*xm^3 =', f8.5)"
	print, format=ch_format, Bm, Dm, Gm
	stop
    endif
; Fin de controle 

; Complement par symetrie (fit d'un modele central sur les frequences >0)
	; La discontinuite est entre les abscisses -1 et +1. Il faut donc met-
	;   tre a zero la valeur obtenue (abusivement) plus haut a l'origine.
    if (i_c eq 0) then begin
	fat = fit(1:nh2)			; usage purement local.
	fit = [-reverse(fat), 0, fat]
;	help, nh2, fit
;    Controle
	icon = 0
	if ((i_s eq 1) and (icon eq 1)) then begin
	    if (ident eq 1) then ch_1 = 'harm EW E1, '
	    if (ident eq 2) then ch_1 = 'harm EW E0, '
	    if (ident eq 3) then ch_1 = 'harm EW NS0_ns, '
	    if (ident eq 4) then ch_1 = 'harm NS NS0_ew, '
	    if (ident eq 5) then ch_1 = 'harm NS NS0_ns, '
	    if (ident eq 6) then ch_1 = 'harm NS NS8, '
	    print, 'FIT_TF_1D : modele central, ' + $
		'controle du complement par symetrie' 
	    absc = -nh2 + indgen(2*nh2 + 1)
	    window, 0	& wset, 0
	    phas = 180/!pi * fit
	    plot, absc, phas, xstyle=1
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, $
		'Fit de phase modele central symetrise ' + ch_1 + '(deg)'
;         Trace axe des abscisses
	    x_a = [-nh2, nh2]	& y_a = [0, 0]
	    oplot, x_a, y_a, linestyle=1
	    stop
	endif
    endif

    goto, a3
; FIN DU CAS A UNE DIMENSION


a2: J_M = 0

; CAS A DEUX DIMENSIONS
; Definition du domaine de contrainte :
;	 - coordonnees (n0x, n0y) du centre de domaine de contrainte, compte
;	     par rapport a l'origine des frequences spatiales situee en milieu
;	     de tableau.
;	 - 1/2 extension nc (1/2 cote du carre du domaine de contrainte).
    if (keyword_set(ident) eq 0) then begin	; fit central ou decale sur TF
	if (i_c eq 0) then begin		; nh1 est ignor'e, nh2 est l'an
						;     cien nh.
	    n0x = 0		& n0y =0	; origine de la TF, pr centre
	    nc = nh2
	endif
	if (i_c gt 0) then begin
	    if (i_c eq 1) then begin		; domaine de fit decale	en u.
		n0x = (nh1 + nh2) / 2
		n0y =  0
	    endif
	    if (i_c eq 2) then begin		; domaine de fit decale	en v.
		n0x =  0
		n0y = (nh1 + nh2) / 2
	    endif
	    nc = abs(nh2 - nh1) / 2		; 1/2 extension
	endif
	x_cd = n2 + n0x	; absc centre domaine de contrainte dans tableau TF.
	y_cd = n2 + n0y	; ord  --------------------------------------------
			;   (tous deux par rapport au coin inferieur gauche).
    endif					; fin du cas fit de TF
    if (keyword_set(ident) eq 1) then begin	; ne peut se grouper avec le 
						;   if suivant (plantage si 
						;   ident n'est pas defini).
	if (ident eq -1) then begin		; fit d'une base.  
	    xm   = nh1
	    ym   = nh2
	    x_cd = nh1	; absc centre domaine de contrainte dans tableau TF.
	    y_cd = nh2	; ord  --------------------------------------------
			;   (tous deux par rapport au coin inferieur gauche).
	    nc   = 16 * npx / 128		; contrainte sur > 1RS^2.
	endif
    endif

    icon = 0
    if (icon eq 1) then begin
	help, af
	ch_format = "(4x, 'nh1 =', i4, 4x, 'nh2 =', i4)"
	print, format=ch_format, nh1, nh2
	ch_format = "(4x, 'n0x =', i4, 4x, 'n0y =', i4, 4x, 'nc =', i4)"
	print, format=ch_format, n0x, n0y, nc
	ch_format = "(4x, 'x_cd =', i4, 4x, 'y_cd =', i4)"
	print, format=ch_format, x_cd, y_cd
	print, '    i_amp_phas =', byte(i_amp_phas)
	stop
    endif

; Generation d'une fonction connue, d'allure impaire. Voir test dans t_cubic.
    imp0 = 0
    if (imp0 eq 1) then begin
	B0  = 0.65
	C0  = 0.32
	G0  = 0.47
	H0  = 0.96
	K0  = 0.76
	L0  = 0.18
	v_l = findgen(2*nh2+1) - nh2
	v_c = replicate(1, 2*nh2+1)
	mx  = v_l # v_c /nh2		; pour faire -1 ou +1 en bord de champ.
	my  = transpose (mx)
	af_c = B0*mx + C0*my + G0*mx^3 + H0*mx^2*my + K0*mx*my^2 + L0*my^3
	af = fltarr(128, 128)
	af(64-nh2, 64-nh2) = af_c
;	tvscl, congrid(af, 512, 512, cubic=-0.5)
;	window, 1	&	wset, 1
;	tvscl,      congrid(af, 512, 512, cubic=-0.5)
;	stop
    endif
; Fin de controle  

    npy  = taille(2)	; npx est definit au debut.

    if(npx ne npy) then begin
	print, 'RH_FIT_CUBIC: le tableau d entree n est pas carre'
	print, '	Dimensions :', nx, ny
	stop
    endif

; Creation du sous-tableau utilise pour le fit et definition du domaine de 
	; contrainte  
	; Rappels : n2     = npx / 2
	;	    x_cd   absc centre domaine de contrainte dans tableau TF,
	;		      avec origine au coin inferieur gauche.
	;	    nc     longueur du 1/2 cote du domaine de contrainte.
    fc = af(x_cd - nc : x_cd + nc,   y_cd - nc : y_cd + nc)
	; fc est fltarr(2*nc+1, 2*nc+1). Le centre  fc(nc, nc)=af(x_cd, y_cd).
    fc_i = fc				; sauvegarde
    icon = 0		; controle plus complet plus bas.
    if (icon eq 1) then begin
	fc_512 = congrid (fc, 512, 512, cubic=-0.5)
	window, 0
	shade_surf, fc_512
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
	    'tableau d''entree sur champ total de contrainte'
	window, 1, xsize=512, ysize=512
	tvscl, fc_512
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
	    'tableau d''entree sur champ total de contrainte'
	stop
	wdel, 0    & wdel, 1
    endif

; Calcul de tcon (indices domaine de contrainte) et tnul pour fit de module
    if (i_amp_phas eq 1) then begin		; cas fit module ou base.
	mom_fc = moment(abs(fc))
	moy = mom_fc(0)
	if (keyword_set(ident) eq 0) then begin	; fit central ou decale sur TF
	    amul = 0.2	; car certaines antennes peuvent etre depointees.
	    fc_min = amul * moy		; seuil de val absolue pour participer
					;   au fit.
	    tcon   = where(abs(fc) gt fc_min)   ; adresses des points ou
						;		fc > fc_min .
	    tnul = where(abs(fc) lt fc_min)	; ---------------- non utilises
	endif
	if (keyword_set(ident) eq 1) then begin	; ne pas grouper les 2 if.
	    if (ident eq -1) then begin  		; fit d'une base.
		; Le max de l'image est au centre du champ de contrainte (dim
		;   2*nc+1). On exclut du fit (en mettant a zero) la zone cen-
		;   trale, la ou est la source compacte. La dimension n'en est 
		;   pas tres critique.
		; Correctif (6 nov 00) : Si on exclut du domaine de contrainte
		;   seulement le carre central fc(nc-nb:nc+nb, nc-nb:nc+nb)
		;   il subsiste la "ligne de crete" NS due aux harm de E0, ce
		;   qui tend a relever le fit dans cette direction et a le
		;   rendre anisotrope, meme si la base est de revolution. On
		;   exclut donc du fit toute le bande verticale. 
;		dist_m = shift(dist(2*nc + 1), nc, nc)
		nb = 4				; 1/2 largeur a la base 
;		fc(nc-nb:nc+nb, nc-nb:nc+nb) = 0	; avant le 6 nov 00.
		fc(nc-nb:nc+nb,      *     ) = 0	; apres -----------
		tcon   = where(abs(fc) gt 0)
		tnul = where(abs(fc) eq 0)
	    endif
	endif
    endif		; fin du cas fit de module ou phase
    if (i_amp_phas eq 2) then begin		; cas fit phase
	; on utilise les tableaux tcon rt tnul calcules au passage precedent
	;   (fit du module) et ici fournis en entree.
    endif

; Controle du sous-tableau total utilise pour le fit (la reduction du domaine
	; de fit au 1/2 plan uv superieur pour la phase est faite plus bas)
    icon = 0
    if ((icon eq 1) and (i_stop eq 1)) then begin
	print, 'fc_i  tableau initial,    fc tableau avec elements mis a zero'
	help, fc, fc_i
	print, 'tcon  tableau des indices des points de contrainte'
	print, 'tnul  ------------------------------ ou fc est nul
	help, tcon, tnul
	window, 0
	shade_surf, congrid(fc_i, 512, 512, cubic=-0.5)
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
							'sous-tableau initial'
	window, 1
	tvscl, congrid(fc_i, 512, 512, cubic=-0.5)
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
							'sous-tableau initial'
	window, 2
	shade_surf, congrid(fc, 512, 512, cubic=-0.5)
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
		'sous-tableau excise, utilise pour le fit'
	window, 3
	tvscl, congrid(fc, 512, 512, cubic=-0.5)
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
		'sous-tableau excise, utilise pour le fit'
	print, '  (la reduction du domaine de fit au 1/2 plan uv superieur ' +$
	    'pour la phase est '
	print, '     faite plus bas)'
	stop
	wdel, 0    &    wdel, 1    &    wdel, 2   &    wdel, 3   
    endif
    ; Conclusion: OK.
; Fin de controle  

; Recherche des indices de ligne (y) et de colonne (ix) correspondant aux 
	; indices contenus dans tcon.
    nr = 2 * nc + 1		; nbre de lignes et colonnes du champ reduit.
				;   nc est 1/2 cote du champ de contrainte.
    iy = tcon / nr
    ix = tcon - iy * nr

    ix = double(ix  - nc)	; indices ramenes au centre du champ reduit.
    iy = double(iy  - nc)
	; ix et iy sont (comme tcon) des tableaux a une seule dimension.

    if (n_elements(ix)  ne  n_elements(iy)) then begin
	print, 'RH_FIT_CUBIC: nbre d abcisses different du nbre d ordonnees'
	print, '     nbre en x,   nbre en y :', n_elements(ix), n_elements(iy)
	stop
    endif

; 1er controle de ix et iy 
    icon = 0
    if ((icon eq 1) and (i_stop eq 1)) then begin
	window, 0	&	wset, 0
	tvscl, congrid(fc, 512, 512, cubic=-0.5)
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
	    'Tableau des points, avec sa dimension en entree'
	window, 1	&	wset, 1
;	print, 'ix =', ix
;	print, 'iy =', iy
	plot, ix, iy, psym=2
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
	    'points couvrant la totalite du domaine de contrainte'
	xyouts, 0.5, 0.92, /normal, alignment=0.5, charsize=chsiz, $
	    '(retrait des points nuls ou du 1/2 plan uv inferieur plus bas)'
	stop
    endif		; fin du controle de ix et iy

; Restriction du domaine de contrainte a 1/2 plan pour les modeles centraux
	; Pour les modeles centraux, la phase est strictement impaire, et on
	;   contraint le fit sur la moitie des points seulement, sans perte
	;   d'information.
	; Contraindre sur 1/2 plan seulement permet en outre de fitter le
	;   saut de phase le long de l'axe u par une simple constante. On
	;   obtient ainsi une bonne description d'un eventuel dephasage EW/NS,
	;   alors que sans cette constante ce dephasage produirait des termes
	;   du 1er et 3eme ordre, qui representeraient d'ailleurs assez mal
	;   la "marche de Heavyside" le long de l'axe u.
	;   En outre, toujours dans le cas des fits centraux, on n'inclura pas
	;   ce terme constant dans le modele, car il ne peut avoir qu'une ori-
	;   gime instrumentale sans rapport avec la structure de la source, et
	;   l'inclure aboutirait a un modele de source distordu, avec un aspect
	;   antilobe dans la direcrion NS.
    if ( (i_amp_phas eq 2)  and  (i_c eq 0)) then begin
	    ; en fait les deux conditions vont ensemble.
	dom_pos = where(iy ge 0)
	ix = ix(dom_pos)
	iy = iy(dom_pos)
	tcon = tcon(dom_pos)
	toto = tcon( where(tcon  gt  (2*nc + 1) * nc -1) )	; = tcon ?
	tnul = tnul( where(tcon  gt  (2*nc + 1) * nc -1) )
	    ; saut de tous les points du 1/plan strictement negatif.
    endif
	
; Controle de ix et iy
    icon = 0
    if ((icon eq 1) and (i_stop eq 1)) then begin
	window, 0	&	wset, 0
	tvscl, congrid(fc, 512, 512, cubic=-0.5)
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
	    'Tableau des points, avec sa dimension en entree'
	window, 1	&	wset, 1
;	print, 'ix =', ix
;	print, 'iy =', iy
	plot, ix, iy, psym=2
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
	    'pts utilises pour le fit (restreint a  y > 0  pour fits ' + $
	    'centraux de phase)'
	help, tcon, ix, iy, toto
	stop
	wdel, 0    & wdel, 1
    endif		; fin du controle de ix et iy
    ; conclusion: OK
; Fin de controle  

; Definition de la fonction de ponderation (fits decales en u)
	; On donne un poids plus grand aux points sur l'axe u dans le cas des
	; modeles decales en u de facon a utiliser les mesures de la fonction
	; de visibilite sur l'axe au dela du pave, ce qui contraint mieux le
	; fit a realiser un lissage la ou on l'utilise (pour recaler directe-
	; ment E1 par rapport a NS0_ns.
    w = replicate(1, 2*nc+1, 2*nc+1)
    if(keyword_set(ident) eq 1)  then begin
	if (ident eq -1) then goto, a4	; saut de la ponderation inhomogene 
					;   dans le cas du fit d'une base.
    endif
;  sur-ponderation de l'axe u.
    if (i_c eq 1) then begin
	mul_int = 1	; ponderation sur l'axe a l'interieur du pave.
	mul_ext = 3	; -----------------------   exterieur -------.
			;   pour que le poids par unite de longueur d'axe soit
			;   comparable dans et hors pave.
			; Remarque (5 sept 00) : il est dangereux de contrain-
			;     dre le fit decale en u au dela des limites du 
			;     "pave" car la visibilite est affectee systemati-
			;     quement par les erreurs de phase de E1 et E0, 
			;     alors que dans le pave il y a compensation des
			;     erreurs sur les phases des multiples antennes de
			;     reference. 
			;   La valeur de mul_ext ici definie ne devrait donc 
			;     pas etre utilisee.
	if (n0x gt 0) then begin
	    n_lim_pav = nc + (16 - n0x)
	    w(0             : n_lim_pav, nc) = mul_int
	    w(n_lim_pav + 1 : 2*nc     , nc) = mul_ext
	endif
	if (n0x lt 0) then begin
	    n_lim_pav = nc + (-16 - n0x)
	    if ((n_lim_pav gt 0) or (n_lim_pav gt 2*nc) ) then begin
		w(0         : n_lim_pav -1, nc) = mul_ext
		w(n_lim_pav : 2*nc        , nc) = mul_int
	    endif else begin		; on n'atteint pas les bords du pave
		w(*, nc) = mul_int
	    endelse
	endif
    endif
a4: J_M = 0
    wt = w(tcon)
; Visualisation de la fonction de ponderation
    icon = 0
    if((icon eq 1) and (i_stop eq 1)) then begin
	window, 0	& wset, 0
	shade_surf, w
	xyouts, /normal, 0.5, 0.97, alignment=0.5, $
		'ponderation pour modele decale dans fit_cubic'
	print, 'RH_FIT_CUBIC :'
	print, '    nbre d elements de w  :', n_elements(w)
	print, '    nbre d elements de wt :', n_elements(wt)
	help, w, wt, ix
	stop
    endif

; Calcul de sommes termes de la matrice em double precision
    wt = double(wt)   & ix = double(ix)   & iy = double(iy)   & fc = double(fc)

    S0    = total (wt   ) 		; = n_elements(x)   sans ponderation.
    Sx1   = total (wt * ix)
    Sy1   = total (wt * iy)

    Sx2   = total (wt * ix^2      )
    Sx1y1 = total (wt * ix   * iy  )
    Sy2   = total (wt *        iy^2)

    Sx3   = total (wt * ix^3      )
    Sx2y1 = total (wt * ix^2 * iy  )
    Sx1y2 = total (wt * ix   * iy^2)
    Sy3   = total (wt *        iy^3)

    Sx4   = total (wt * ix^4      )
    Sx3y1 = total (wt * ix^3 * iy  )
    Sx2y2 = total (wt * ix^2 * iy^2)
    Sx1y3 = total (wt * ix   * iy^3)
    Sy4   = total (wt *        iy^4)

    Sx5   = total (wt * ix^5      )
    Sx4y1 = total (wt * ix^4 * iy  )
    Sx3y2 = total (wt * ix^3 * iy^2)
    Sx2y3 = total (wt * ix^2 * iy^3)
    Sx1y4 = total (wt * ix   * iy^4)
    Sy5   = total (wt *        iy^5)

    Sx6   = total (wt * ix^6      )
    Sx5y1 = total (wt * ix^5 * iy  )
    Sx4y2 = total (wt * ix^4 * iy^2)
    Sx3y3 = total (wt * ix^3 * iy^3)
    Sx2y4 = total (wt * ix^2 * iy^4)
    Sx1y5 = total (wt * ix   * iy^5)
    Sy6   = total (wt *        iy^6)

; Calcul des sommes du vecteur membre de droite
    Sf0    = total (wt * fc(tcon)               )
    Sfx1   = total (wt * fc(tcon) * ix          )
    Sfy1   = total (wt * fc(tcon)        * iy   )

    Sfx2   = total (wt * fc(tcon) * ix^2        )
    Sfx1y1 = total (wt * fc(tcon) * ix    * iy  )
    Sfy2   = total (wt * fc(tcon)         * iy^2)
    
    Sfx3   = total (wt * fc(tcon) * ix^3        )
    Sfx2y1 = total (wt * fc(tcon) * ix^2  * iy  )
    Sfx1y2 = total (wt * fc(tcon) * ix    * iy^2)
    Sfy3   = total (wt * fc(tcon)         * iy^3)
    

; Restauration en simple precision
    wt = float(wt)    & ix = float(ix)    & iy = float(iy)    & fc = float(fc)

; Resolution du systeme lineaire
    if (i_c eq 0) then begin		
	    ; fit avec termes de degre 0  1  et  3, contraints sur le 1/ plan 
	    ;    y>0 ou nul.
	if (i_phi_lin eq 0) then begin	
		; termes de degre 0 et 3 deg seuls. C'est le cas pour les fits
		;   de phase des modeles 2D centraux (le terme lineaire cor-
		;   respond a un decalage de position, indetectable dans le cas
		;   d'une calibration "auto").
			; Relique valable pour degre 3 seul
			;    mat = [[Sx6  ,   Sx5y1,   Sx4y2,   Sx3y3], $
			;	    [Sx5y1,   Sx4y2,   Sx3y3,   Sx2y4], $
			;	    [Sx4y2,   Sx3y3,   Sx2y4,   Sx1y5], $
			;	    [Sx3y3,   Sx2y4,   Sx1y5,   Sy6  ]]
			;   vec =   [Sfx3 ,   Sfx2y1,  Sfx1y2,  Sfy3 ]

	    mat =  [[S0   ,  Sx3  ,  Sx2y1,  Sx1y2,  Sy3  ], $
		    [Sx3  ,  Sx6  ,  Sx5y1,  Sx4y2,  Sx3y3], $
		    [Sx2y1,  Sx5y1,  Sx4y2,  Sx3y3,  Sx2y4], $
		    [Sx1y2,  Sx4y2,  Sx3y3,  Sx2y4,  Sx1y5], $
		    [Sy3  ,  Sx3y3,  Sx2y4,  Sx1y5,  Sy6  ]]

	    vec =   [Sf0  ,  Sfx3 ,  Sfx2y1, Sfx1y2, Sfy3]
  
	    if (i_sys_lin eq 1) then  res = CRAMER       (mat, vec)
	    if (i_sys_lin eq 2) then  res = RH_LINEAR_LU (mat, vec, i_stop)
	    if (i_sys_lin eq 3) then  res = RH_LINEAR_SVD(mat, vec, i_stop)

	    A = float ( res(0) )
	    G = float ( res(1) )
	    H = float ( res(2) )
	    K = float ( res(3) )
	    L = float ( res(4) )

	    AA = A	; sauvegarde du scalaire. Le choix d'inclure A dans le
			;   modele (pour controle seulement) se fait plus bas
			;   avec le choix de fac_A.
	    B = 0  & C = 0  & D = 0   & E = 0   & F = 0
	endif		; fin du fit sans terme constant ni termes lineaires.
	if (i_phi_lin eq 1) then begin	; termes de degre 0, 1, 3 (sans 2)
		; Ce cas est sans usage au 10 dec 04. Il est conserve pour etre
		; complet.
		    ; Relique valable pour degres 1 et 3 seuls
		    ; mat = $
		    ;      [[Sx2  ,  Sx1y1,  Sx4  ,  Sx3y1,  Sx2y2,  Sx1y3], $
		    ;       [Sx1y1,  Sy2  ,  Sx3y1,  Sx2y2,  Sx1y3,  Sy4  ], $
		    ;       [Sx4  ,  Sx3y1,  Sx6  ,  Sx5y1,  Sx4y2,  Sx3y3], $
		    ;       [Sx3y1,  Sx2y2,  Sx5y1,  Sx4y2,  Sx3y3,  Sx2y4], $
		    ;       [Sx2y2,  Sx1y3,  Sx4y2,  Sx3y3,  Sx2y4,  Sx1y5], $
		    ;       [Sx1y3,  Sy4  ,  Sx3y3,  Sx2y4,  Sx1y5,  Sy6  ]]
		    ; vec = [Sfx1 ,  Sfy1 ,  Sfx3 ,  Sfx2y1, Sfx1y2, Sfy3 ]

	    mat =  [[S0   ,  Sx1  ,  Sy1  ,  Sx3  ,  Sx2y1,  Sx1y2,  Sy3  ], $
		    [Sx1  ,  Sx2  ,  Sx1y1,  Sx4  ,  Sx3y1,  Sx2y2,  Sx1y3], $
		    [Sy1  ,  Sx1y1,  Sy2  ,  Sx3y1,  Sx2y2,  Sx1y3,  Sy4  ], $
		    [Sx3  ,  Sx4  ,  Sx3y1,  Sx6  ,  Sx5y1,  Sx4y2,  Sx3y3], $
		    [Sx2y1,  Sx3y1,  Sx2y2,  Sx5y1,  Sx4y2,  Sx3y3,  Sx2y4], $
		    [Sx1y2,  Sx2y2,  Sx1y3,  Sx4y2,  Sx3y3,  Sx2y4,  Sx1y5], $
		    [Sy3  ,  Sx1y3,  Sy4  ,  Sx3y3,  Sx2y4,  Sx1y5,  Sy6  ]]

	    vec =   [Sf0  ,  Sfx1 ,  Sfy1 ,  Sfx3 ,  Sfx2y1, Sfx1y2, Sfy3]

	    if (i_sys_lin eq 1) then  res = CRAMER       (mat, vec)
	    if (i_sys_lin eq 2) then  res = RH_LINEAR_LU (mat, vec, i_stop)
	    if (i_sys_lin eq 3) then  res = RH_LINEAR_SVD(mat, vec, i_stop)

	    A = float ( res(0) )
	    B = float ( res(1) )
	    C = float ( res(2) )
	    G = float ( res(3) )
	    H = float ( res(4) )
	    K = float ( res(5) )
	    L = float ( res(6) )

	    AA = A	; sauvegarde du scalaire. Le choix d'inclure A dans le
			;   modele (pour controle seulement) se fait plus bas
			;   avec le choix de fac_A.
	    D = 0   & E = 0   & F = 0
	endif	; fin du fit sans terme constant mais avec les termes lineaires
    endif			; fin du fit 2D central (impair).
    if ((i_c eq 1) or (i_c eq 2))then begin	; fit 3eme degre general.
	mat = $
      [[S0  , Sx1  , Sy1  , Sx2  , Sx1y1, Sy2  , Sx3  , Sx2y1, Sx1y2, Sy3  ], $
      [Sx1  , Sx2  , Sx1y1, Sx3  , Sx2y1, Sx1y2, Sx4  , Sx3y1, Sx2y2, Sx1y3], $
      [Sy1  , Sx1y1, Sy2  , Sx2y1, Sx1y2, Sy3  , Sx3y1, Sx2y2, Sx1y3, Sy4  ], $
      [Sx2  , Sx3  , Sx2y1, Sx4  , Sx3y1, Sx2y2, Sx5  , Sx4y1, Sx3y2, Sx2y3], $
      [Sx1y1, Sx2y1, Sx1y2, Sx3y1, Sx2y2, Sx1y3, Sx4y1, Sx3y2, Sx2y3, Sx1y4], $
      [Sy2  , Sx1y2, Sy3  , Sx2y2, Sx1y3, Sy4  , Sx3y2, Sx2y3, Sx1y4, Sy5  ], $
      [Sx3  , Sx4  , Sx3y1, Sx5  , Sx4y1, Sx3y2, Sx6  , Sx5y1, Sx4y2, Sx3y3], $
      [Sx2y1, Sx3y1, Sx2y2, Sx4y1, Sx3y2, Sx2y3, Sx5y1, Sx4y2, Sx3y3, Sx2y4], $
      [Sx1y2, Sx2y2, Sx1y3, Sx3y2, Sx2y3, Sx1y4, Sx4y2, Sx3y3, Sx2y4, Sx1y5], $
      [Sy3  , Sx1y3, Sy4  , Sx2y3, Sx1y4, Sy5  , Sx3y3, Sx2y4, Sx1y5, Sy6  ]]

	vec = [Sf0, Sfx1, Sfy1, Sfx2, Sfx1y1, Sfy2, Sfx3, Sfx2y1, Sfx1y2, Sfy3]

	if (i_sys_lin eq 1) then  res = CRAMER       (mat, vec)
	if (i_sys_lin eq 2) then  res = RH_LINEAR_LU (mat, vec, i_stop)
	if (i_sys_lin eq 3) then  res = RH_LINEAR_SVD(mat, vec, i_stop)
	A = float ( res(0) )
	B = float ( res(1) )
	C = float ( res(2) )
	D = float ( res(3) )
	E = float ( res(4) )
	F = float ( res(5) )
	G = float ( res(6) )
	H = float ( res(7) )
	K = float ( res(8) )
	L = float ( res(9) )
    endif

; Controle du fit et comparaison avec la fonction connue (passee de t_cubic)
    icon = 0
    if ((icon eq 1) and (i_stop eq 1)) then begin
      ; renormalisation pour comparaison avec la simulation (passe par t_cubic)
	nc2 = nc^2
	nc3 = nc^3
	B2 = B * nc     & C2 = C * nc
	D2 = D * nc2    & E2 = E * nc2    & F2 = F * nc2
  	G2 = G * nc3    & H2 = H * nc3    & K2 = K * nc3    & L2 = L * nc3
	print, 'Valeurs comparees des coeff entres et calcules:'
;	ch = '        B             C             G           H' + $
;		'           K           L'
;	print, ch
;	print, B0,  C0,  G0,  H0,  K0,  L0	; supprime pour test de t_cubic
	print, 'RH_FIT_CUBIC,  resultats :'
	print, format="(4x, 'A =', f5.2)", A
	print, format="(4x, 'B =', f5.2, 4x, 'C =', f5.2)", B2 , C2
	print, format="(4x, 'D =', f5.2, 4x, 'E =', f5.2, 4x, 'F =', f5.2)", $
							D2,  E2,  F2
	ch_format = "(4x, 'G =', f5.2, 4x, 'H =', f5.2, 4x, " + $
		"'K =', f5.2, 4x, 'L =', f5.2)"
	print, format=ch_format, G2 , H2 , K2 , L2 
	stop
		; Verification le 10 dec 04 avec :
		;  . i_c = 0  (fit phase des modeles centraux)
		;  . i_amp_phas = 2
		;  . i_phi_lin = 0 et 1
		;  . reduction du domaine de fit au 1/2 plan uv >0 ou nul
		;	pour pouvoir decrire la "marche de Heavyside"
		; Conclusion: valeurs identiques, OK 
    endif		; fin de controle 
    
;  Construction de deux matrices, mx et my, de memes dimensions que la portion
	;   concernee par le fit et contenant respectivement les indices de
	;   colonne et de ligne dans cette portion, indices comptes a partir 
	;   du centre du domaine de contrainte. Pour eviter de manipuler les 
	;   elements de tableau en utilisant leur indices.
	; Faute trouvee le 27 juin 2000 : 
	;   	n_col = max(ix) - min(ix) + 1		; nbre de colonnes.
	;   	n_lig = max(iy) - min(iy) + 1		; nbre de lignes.
	;	vx = findgen(n_col) + min(ix)
	;	vy = findgen(n_lig) + min(iy)
	;   Cela n'est vrai que pour les elements non nuls de fc, mais la 1ere
	;   et/ou la derniere colonne peuvent etre nulles dans le cas des visi-
	;   bilites ou les harm EW impairs sont nuls sauf sur l'axe u. Le cas
	;   se presente donc pour les fits decales. Par contre il n'y avait 
	;   pas de faute pour les fits centres 
    n_col =  2 * nc + 1		; nbre de colonnes, eviter le nom "nc".
    n_lig =  2 * nc + 1		; nbre de lignes.
    vx = lindgen(n_col) - nc	; passage en long integer le 4 jul 2000.
    vy = lindgen(n_lig) - nc
	; vx et vy sont les vecteurs des colonnes et lignes (rangees par
	;  valeurs croissantes) ou sont situes les points du champ reduit, 
	;  comptees a partir du centre du champ.

    mx = vx # replicate (1, n_elements(vy))	; n_lig lignes   identiques.
    my = replicate (1, n_elements(vx)) # vy	; n_col colonnes identiques.

; Traitement de la "marche d'Heavyside" de 1/2 hauteur A, pour la phase des
	; modeles centraux. Choix de l'inclure (controle) ou non.
    if (i_c eq 0) then begin 
	A = fltarr(n_col, n_lig)		; initialisation (nulle).
	dom_p = where (my gt 0)		; 1/2 plan uv superieur.
	dom_n = where (my lt 0)		; ----------- inferieur.
	A(dom_p) =  AA
	A(dom_n) = -AA
;	fac_A = 0	; 1 pour inclure AA dans le modele. Usuel 0 ici.
;	A = fac_A * A	;   Meilleure rustine ci-dessous
    endif

; Calcul de la fonction fit complete sur tout le domaine du fit (pts non fit-
	; tes inclus).
    fit_A  = A  +  B*mx  +  C*my    +  D*mx^2     +  E*mx*my    +  F*my^2  + $
			    G*mx^3  +  H*mx^2*my  +  K*mx*my^2  +  L*my^3
    fit = fit_A
	; rappel : si i_c = 0 , A ets une matrice avec un echelon de Heavyside
	;	le long de l'axe u
;  Retrait de A pour le fit de la phase des modeles centraux (de facon a 
	;   attribuer cette marche h'Heavyside aux phases instrumentales)
	; On conserve fit_A pour des controles eventuels.
    if (i_c eq 0) then fit = fit_A - A
    diff_1 = fc(tcon) - fit(tcon)			; diff_1 tableau 1D.
    res    = sqrt ( total(diff_1^2) / total(fc^2) )	; residu relatif
    fit2   = fit
    fit2(tnul) = 0	; pour comparer avec les donnees reelles
    
    diff_2 = fc - fit2		; diff tableau a deux dimension pour tracer.

; Controle du fit
;  visualisation 2D.
    icon = 0
    if ((icon eq 1) and (i_stop eq 1)) then begin
	i_sh_tv = 1		; 1 shade_surf,  2 tvscl
;     Rustine pour graduer en degres les traces des phases des modeles centraux
	fac = 1
	ch_lab = ''
;	if (fac_A eq 0) then  ch_0 = 'echelon // axe u non inclus'
;	if (fac_A eq 1) then  ch_0 = 'echelon // axe u inclus'
	if (i_c eq 0) then  ch_0 = 'echelon // axe u non inclus'
	if (i_c gt 0) then  ch_0 = 'composante continue incluse'
	if (i_c eq 0) then begin
	    fac = 180/!pi
	    ch_lab = ' (degres)'
	endif
;     Visualisation de la partie de af a fitter et des fits.
	window, 0
	if (i_sh_tv eq 1) then shade_surf, fac*congrid(fc, 512, 512,cubic=-0.5)
	if (i_sh_tv eq 2) then tvscl     , fac*congrid(fc, 512, 512,cubic=-0.5)
	if (keyword_set(ident) eq 0) then begin		; cas fit TF.
	    ch1 = 'fonction de contrainte'
	    xyouts, /normal, 0.5, 0.97, alignment=0.5, charsize=chsiz, $
		ch1 + ' sur son champ originel' + ch_lab
	endif
	if (keyword_set(ident) eq 1) then begin		; cas fit base 2D.
	    ch1 = 'sous-tableau excise '
	    ch2 = 'utilise pour le fit'
	    xyouts, /normal, 0.5, 0.97, alignment=0.5, charsize=chsiz, $
						ch1 + ch2 + ch_lab
	endif

	window, 1	&	wset, 1
	if (i_sh_tv eq 1) then shade_surf, fac*congrid(fit, 512,512,cubic=-0.5)
	if (i_sh_tv eq 2) then tvscl     , fac*congrid(fit, 512,512,cubic=-0.5)
	xyouts, /normal, 0.5, 0.97, alignment=0.5, charsize=chsiz, $
	    'fit sur champ originel de la fonction de contrainte' + ch_lab
	xyouts, /normal, 0.5, 0.92, alignment=0.5, charsize=chsiz, ch_0	

	window, 2	&	wset, 2
	if(i_sh_tv eq 1) then shade_surf,fac*congrid(diff_2,512,512,cubic=-0.5)
	if(i_sh_tv eq 2) then tvscl     ,fac*congrid(diff_2,512,512,cubic=-0.5)
	xyouts, /normal, 0.5, 0.97, alignment=0.5, charsize=chsiz, $
		ch1 + ' - fit (sur champ originel)' + ch_lab
	xyouts, /normal, 0.5, 0.92, alignment=0.5, charsize=chsiz, $
			ch_0 + ' dans le fit'	

	print, '    residu relatif:', res
	print, ' '
;	print, 'Fit anisotrope impair de degre 3:'
;	ch_format = "('    B =', f8.5, '   C =', f8.5, '   G =', f8.5, " + $
;		"'   H =', f8.3)"
;	print, format=ch_format, B, C, G, H
	ch_1 = 'RH_FIT_CUBIC : arret de controle pour '
	if (i_c eq 0) then ch_2 = 'modele centre'
	if (i_c eq 1) then begin
	    if (keyword_set(ident) eq 0) then $		; cas fit TF.
			   ch_2 = 'modele decale en u'
	    if (keyword_set(ident) eq 1) then $		; cas fit base 2D.
			   ch_2 = 'modele de base 2D'
	endif
	if (i_c eq 2) then ch_2 = 'modele decale en v'
	print, ch_1 + ch_2
	stop
    endif
;  Visualisation sur l'axe u.
    icon = 0
    if ((icon eq 1) and (i_stop eq 1)) then begin
	absc = (nh1<nh2) + indgen(2*nc + 1)
	window, 0	&	wset, 0
	plot, title='coupe EW (fonc init), fit ...', $
		absc, fc(*, nc)
	oplot, absc, fit(*, nc), linestyle=1
	window, 1	&	wset, 1
	plot, title='coupe EW (fonction initiale - fit)', $
		absc, diff_2(*, nc)
	window, 2	& wset, 2
	shade_surf, w
	xyouts, /normal, 0.5, 0.97, alignment=0.5, 'fonction de ponderation'
	stop
    endif
    ; conclusion:
; Fin de controle  
; FIN DU CAS A DEUX DIMENSIONS.

a3: J_M = 0	; fin du saut du cas a deux dimensions.

    end		; fin de RH_FIT_CUBIC


