PRO RH_FIT_QUARTIC, ident=ident,  i_stop,  i_sys_lin, $	; entree (parametres).
		 af_1,  n1_1,			      $	; entree (donnees).
		 tcon, tnul, n_tnul,    	      $	; sortie pour 
							;       RH_FIT_CUBIC
		 A, B, C, D, E, F, G, H, K, fit		; sortie

    ; A est la composante continue. B ... K sont les coeff des monomes de 
    ;   degre 2 et 4.
    ;
    ; Determine un fit pair anisotrope du 4eme degre:
    ;
    ;   F_a = A + B i2 + C ij + D j2  +  E i4 +  F i3j + G i2j2 + H ij3 + K j4
    ;
    ; d'une fonction af a partir du tableau:
    ;		af(np/2-n1 : np/2+n1, np/2-n1 : np/2+n1).
    ;
    ; Le fit est limite a un carre de (2*n1 + 1) * (2*n1 + 1) pts centre
    ;   sur le centre du champ. 
    ; On ne tient compte que des points qui sont superieurs a une certaine 
    ;   fraction de la moyenne des pts entourant le point central (definition 
    ;   du tableau tcon). Ceci pour fitter de facon realiste la visibilite
    ;   dans le cas ou il y a plus d'un centre actif sur le soleil (l'ampli-
    ;   tude pouvant alors etre fortement anisotrope (modulation selon la di-
    ;   rection joignant les centres.

    ; Si le tableau en entree est a une dimension le fit l'est aussi. Seuls
    ;   A, B et E sont significatis.  C, D, F, G, H et K sont bidon (nuls). 
    ; le mot-cle ident ne sert qu'au cas a une dimension (pour eviter de modi-
    ;   fier la liste des argument du cas a deux dimensions.

; Modifications :
; 00 fev 28	Creation
;    mar 10	Complete a une dimension
;    oct 13	Modif calcul du niveau min pour participer a la contrainte
;		  (reprise de fit_quadric et destinee a accepter de fortes 
;		  bases).
; 01 mar 26	remplacement de CRAMER par RH_LINEAR_SVD, consider'e comme plus
;		  fiable. Fait aissi dans RH_FIT_QUADRIC et RH_FIT_CUBIC.

; Notations :
; af_1		fonction a fitter.
; n1_1		harmonique max du domaine de contrainte.

; print, 'RH_FIT_QUARTIC : entree'

    icon = 0
    if ((icon eq 1) and (i_stop eq 1))  then  begin
	help,  ident,  i_stop,  i_sys_lin,  af_1,  n1_1
	stop
    endif

    chsiz = 1.3

; Conversion en double precision pour eviter des overflows (on eleve a des 
	; puissances elevees).
    n1 = long(n1_1)
    af = double(af_1)

    taille = size(af)
    n_dim = taille(0)
    if(n_dim eq 0) then begin
	print, 'RH_FIT_QUARTIC : le tableau en entree a la dimension 0'
	stop
    endif
    if (n_dim eq 1) then goto, a1
    if (n_dim eq 2) then goto, a2
    if(n_dim gt 2) then begin
	print, 'RH_FIT_QUARTIC : le tableau en entree a une dimension > 2'
	stop
    endif
    
; DEBUT DU CAS A UNE DIMENSION
a1: J_M = 0
; Generation d'une fonction connue
    imp0 = 0
    if (imp0 eq 1) then begin
	n = 128L
	ad = findgen(n) - n/2	; distance au point central (n/2). 
	r2   = ad^2
	r4   = ad^4
	bmul = 0.6	; variation entre le centre et n1 du terme 2eme deg.
	emul = 0.1	; variation entre le centre et n1 du terme 4eme deg.
	A0   = 1.0	; terme constant.
	B0   = -bmul / (n/2)^2
	E0   =  emul / (n/2)^4
	af   = double(A0  +  B0 * r2  +  E0 * r4)
	window, 0	&	wset, 0
	plot, af(n/2-n1 : n/2+n1), $
		title='fonction connue sur intervalle de fit'
	print, 'A0 =', A0, '      B0 =', B0, '      E0 =', E0
	stop
    endif
    ; conclusion:
; Fin de controle  

    npx  = taille(1)    
    n2 = npx / 2

	; Rappel des valeurs de ident:  
	;  1 pour  E1     avec E1  a H16   (harmoniques impairs nuls), 
	;  2 pour  E0     avec E1  a H16   (harmoniques   pairs nuls), 
	;  3 pour  NS0_ns avec E1  a H16   (indice = rang des harmoniques),  
	;  4 pour  NS0_ew avec NS0 a NS45  (indice = rang des harmoniques),  
	;  5 pour  NS0_ns avec NS7 a NS45  (indice = rang des harmoniques et 
	;				    les harm 1 a 6 sont nuls), 
	;  6 pour  NS8    avec NS0 a NS17  (indice n'est pas le rang des harm).

	; Rappel : n1 est le rang de l'harm max du domaine de contrainte (nh2
	;	dans FIT_TF_1D).

; Creation du sous-tableau utilise pour le fit. Le fit se fait sur un sous en-
	; semble de ce tableau, ou l'amplitude des harmoniques est suffisante.
    fc = af(n2 - n1  :  n2 + n1)	; Rappel: n2 = npx / 2, n1 nbre d'harm
					;   pour contraindre le fit.
;    if (ident eq 5) then begin
;	fc = af(n2-6-n1 : n2+6+n1)	; faute idiote jusqu'au 24 nov 00.
;    endif		
    	; fc est un fltarr(2*n1+1). le centre est fc(n1) sauf pour ident=5 ou
	;  le centre est en fc(n1+6).

; Mise a zero des harm proches de l'origine (uniquement pour tester les fits
	; Cramer, LU et SVD avec des gaps dans les donnees)
    i_essaI = 0
    if (i_essai eq 1) then begin
	print,  'RH_FIT_QUARTIC : gap pour tester CRAMER, RH_LINEAR_LU ' + $
		'et LINEAR_SVD'
	n_inf = -14
	n_sup =  14
	fc(n1+n_inf : n1+n_sup) = 0
    endif

; Controle de fc
    icon = 0
    if ((icon eq 1) and (i_stop eq 1))  then begin
	print, 'fit_quartic : controle de fc'
	print, '     harm max du domaine de contrainte :', n1
	window, 1
	plot, fc
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=chsiz, $
	    'valeurs sur le domaine de contrainte'
	stop
	wdel, 1
    endif

;  Calcul d'une moyenne de l'amplitude des harmoniques.
    if ((ident eq 1) or (ident eq 3)) then begin    ; harm EW pairs.
	if (imp0 eq 0) then begin		    ; imp0=0 est le cas usuel.
;	    fc_moy = total(fc(n1-4:n1+4)) / 4	    ; moy sur -4 -4  2 4
	    fc_moy = (total(fc(n1-10 :n1 -4)) + $   ; moy sur -10 -8  -6  -4 et
		      total(fc(n1 +4 :n1+10)) ) / 8 ;	        4  6   8  10 . 
	endif
	if (imp0 eq 1) then begin			; vestige mise au point
	    fc_moy = total(fc(n1-2:n1+2)) / 5		; pour fonction connue
	endif
    endif 
     if (ident eq 2) then begin			; E0, harm EW impairs.
;	fc_moy =  total(fc(n1 - 5 : n1 + 5)) / 6   ; moy sur -5 -3 -1  1 3 5
	fc_moy = (total(fc(n1 - 9 : n1 - 3)) + $   ; moy sur -9  -7 - 5  -3 et
		  total(fc(n1 + 3 : n1 + 9)) )/ 8  ;	      3   5   7   9
    endif
     if (ident eq 3) then begin			   ; NS0_ns, harm EW pairs
	fc_moy = (total(fc(n1 - 8 : n1 - 4)) + $   ; moy  sur  -8  -6 - 4  
		  total(fc(n1 + 4 : n1 + 8)) )/ 6  ;   et sur   4   6   8
    endif
     if (ident eq 4) then begin			; harm NS avec NS0_ew.
;	fc_moy = total(fc(n1-4:n1+4)) / 8	; moy sur -4 a 4, 0 exclus
	fc_moy = (total(fc(n1 - 9 : n1 -  3)) + $	; moy  sur [-9, -3]
		  total(fc(n1 + 3 : n1 +  9)) ) / 14	;   et sur [ 3,  9]
    endif
     if (ident eq 5) then begin			; harm NS avec NS0_ns.
;	fc_moy = total(fc(n1+6-9:n1+6+9)) / 6	;  moy sur 7 a 9 (13 elem nuls
						;    avant complement h_NS0_ns)
;	fc_moy = total(fc(n1-4:n1+4)) / 8	; moy sur -4 a 4, 0 exclus
	fc_moy = (total(fc(n1 - 9 : n1 - 3)) + $	; moy sur [-9, -3]
		  total(fc(n1 + 3 : n1 + 9)) ) / 14	;  et sur [ 3,  9].
    endif
     if (ident eq 6) then begin			; harm NS avec NS8
	fc_moy = (total(fc(n1 - 8 : n1 - 3)) + $	; moy sur  [-8, -3]
		  total(fc(n1 + 3 : n1 + 8)) ) / 12	;   et sur [ 3,  8]
    endif
 
    frac = 0.3		; fraction min de la moyenne pour um harm acceptable.
    fc_min = fc_moy * frac
    fc_max = fc_moy / frac	; pour eliminer le 1er harmonique, peut-etre
				;   mal corrige de base (l'origine a ete mise
				;   a zero dans FIT_TF_1D).
				; On exclu explicitement ci-dessus les bases 
				;   courtes de la moyenne. Il faut maintenant
				;   les exclure du domaicne de contrainte 
				;   (mofid du 8 dec 04).
    tcon = where((fc gt fc_min)	and (fc lt fc_max))
    tcon = tcon (where( (tcon ne n1-2) and (tcon ne n1-1) and $
			(tcon ne n1+1) and (tcon ne n1+2) ) )	
				; elimination dure des bases  -2  -1  +1  +2.
	; tcon est l'ensemble des adresses des points ou fc > fc_min.
    tnul = where(abs(fc) lt fc_min, n_tnul)	; sortie pour RH_FIT_CUBIC.
    x    = tcon - n1				; abscisses points fc > fc_min.
    n_x  = n_elements(x)
    n2   = npx / 2


; Controle de x
    icon = 0
    if ((icon eq 1) and (i_stop eq 1))  then begin
	print, '    RH_FIT_QUARTIC : controle de fc et de x'
	print, '        fc_moy =', fc_moy
	print, '        harm max du domaine de contrainte :', n1
	plot, fc, xstyle=1
	print, '        indices de fc contraignants :', tcon
	print, '        abscisses de contrainte :', x
	stop
    endif
    ; conclusion: OK, y compris pour les harm NS de NS8.
; Fin de controle  


; Calcul (en double precision) de sommes du calcul des moindres carres
    x = double(x)	& fc = double(fc)

    S0    = n_x

    Sx2   = total(x^2) 
    Sx4   = total(x^4)
    Sx6   = total(x^6)
    Sx8   = total(x^8)

    Fx0   = total(fc(tcon)      )
    Fx2   = total(fc(tcon) * x^2) 
    Fx4   = total(fc(tcon) * x^4) 

    mat = $
    [[S0   ,  Sx2  ,  Sx4], $
     [Sx2  ,  Sx4  ,  Sx6], $
     [Sx4  ,  Sx6  ,  Sx8]]

    vec = [Fx0,  Fx2,  Fx4]

    x = float(x)	& fc = float(fc)	; restauration simple precision

; Comparaison des resolutions Cramer LU SVD
    i_compar = 0
    if ((i_compar eq 1) and (i_stop eq 1))  then begin
	resultat = CRAMER    (mat, vec)
	A_c = resultat (0)
	B_c = resultat (1)
	E_c = resultat (2)
	resultat = RH_LINEAR_LU (mat, vec, i_stop)
	A_l = resultat (0)
	B_l = resultat (1)
	E_l = resultat (2)
	resultat = RH_LINEAR_SVD(mat, vec, i_stop)
	A_s = resultat (0)
	B_s = resultat (1)
	E_s = resultat (2)
    endif
    
; Resolution du systeme lineaire
    if (i_sys_lin eq 1) then  resultat = Cramer       (mat, vec)
    if (i_sys_lin eq 2) then  resultat = RH_LINEAR_LU (mat, vec, i_stop)
    if (i_sys_lin eq 3) then  resultat = RH_LINEAR_SVD(mat, vec, i_stop)
	; Faute trouvee le 11 dec 01 : 2 pour SVD et 3 pour LU (cas 1D seul)
	;    meme faute dans RH_FIT_QUARTIC (mais pas dans RH_FIT_CUBIC).
    A = resultat (0)
    B = resultat (1)
    E = resultat (2)
    C = 0
    D = 0
    F = 0
    G = 0
    H = 0
    K = 0

;  Construction du vecteur vx, de dimensions (2*n1+1), comme le tableau fc 
	; defini plus haut. Le modele est calcule sur vx, de dimension bien 
	; determinee, alors que le calcul du fit se fait sur le sous-ensemble
	; de ce domaine ou les harmoniques ont des amplitudes suffisantes. 
    vx = indgen(2*n1+1) - n1

; Calcul du ou des fit sur tout le domaine du fit (pts non fittables inclus).
    if ((i_compar eq 1) and (i_stop eq 1))  then  begin
	fit_cram = A_c  +  B_c * vx^2  +  E_c * vx^4
	fit_lu   = A_l  +  B_l * vx^2  +  E_l * vx^4
	fit_svd  = A_s  +  B_s * vx^2  +  E_s * vx^4
    endif
    fit = A  +  B * vx^2  +  E * vx^4
    c_c_q = A					; q comme quartique.

; Comparaison Cramer - SVD (i_compar est defini plus haut)
    if ((i_compar eq 1) and (i_stop eq 1))  then begin
	window, 0
	ymax = 1.2 * (max(fc) > max(fit_cram) > max(fit_lu) > max(fit_svd))
;	absc = indgen(2*n1+1) - n1	; pour des modeles symetriques.
	absc = indgen(2*n1+1)
	plot,  absc, fc, xstyle=1, yrange=[0, ymax], ystyle=1
	oplot, absc, fit_cram * 1.00, linestyle=1
	oplot, absc, fit_lu   * 1.005, linestyle=2
	oplot, absc, fit_svd  * 0.995, linestyle=4
	    ; 0	Solid,  1 Dotted,  2 Dashed,  3	 Dash Dot,  4 Dash Dot Dot Dot,
	    ; 5	Long Dashes.	
	xyouts, 0.5, 0.97, /normal, alignment=0.5, $
	    'RH_FIT_QUARTIC : donnees ___, Cramer ..., LU _ _ _, SVD _..._'
	stop
    endif

; Controle du fit et visualisation.
    icon = 0
    if ((icon eq 1) and (i_stop eq 1))  then begin
;     Visualisation de la partie de af a fitter et du fit.
	window, 0	&	wset, 0
	plot, fc, xstyle=1
	xyouts, 0.5, 0.07, /normal, alignment=0.5, charsize=chsiz, $
		'fonction en entree (domaine du fit)'
	window, 1	&	wset, 1
	plot, Fit, xstyle=1, title='fonction fit (domaine du fit)'

	if (imp0 eq 1) then begin
	    print, 'Comparaison des valeurs vraies et fittees de A, B, E'
	    print, '    A0 =', A0, '      B0 =', B0, '      E0 =', E0
	endif
	print, 'Fit 4eme degre:'
	    print, '     A =', A, '       B =', B, '       E =', E
;	ch_format = "('    A =', f8.5, '   B =', f8.5, '   E =', f8.5)"
;	print, format=ch_format, A, B, E
	stop
	wdel, 0    & wdel, 1
    endif
    ; conclusion:
; Fin de controle  

    goto, a3
; FIN DU CAS A UNE DIMENSION



; DEBUT DU CAS A DEUX DIMENSIONS
a2: J_M = 0
; Generation d'une fonction connue
    imp0 = 0
    if (imp0 eq 1) then begin
	n = 128L
	ad = shift(dist(n), n/2, n/2)    
		; "distance", 0 en (n/2,n/2), n/2 au bord. 
	r2   = ad^2
	r4   = ad^4
	bmul = 0.6	; variation entre le centre et n1 du terme 2eme deg.
	emul = 0.1	; variation entre le centre et n1 du terme 4eme deg.
	A0   = 1.0	; terme constant.
	B0   = -bmul / (n/2)^2
	E0   =  emul / (n/2)^4
	af   = double(A0  +  B0 * r2  +  E0 * r4)
;	af(*, *) = 1
	window, 0	&	wset, 0
	shade_surf, congrid(af, 512, 512, cubic=-0.5)
	window, 1	&	wset, 1
	tvscl,      congrid(af, 512, 512, cubic=-0.5)
	stop
    endif
    ; conclusion:
; Fin de controle  

    dim  = size(af)
    npx  = dim(1)    
    npy  = dim(2)

    if(npx ne npy) then begin
	print, 'RH_FIT_QUARTIC: le tableau d entree n est pas carre'
	print, '	Dimensions :', nx, ny
	stop
    endif

    n2 = npx / 2

; Creation du sous-tableau utilise pour le fit. 
	; A la difference de fit_quadric on ne met pas a zero la partie cen-
	; trale a laquelle contribue la base. La raison (pas absolue) est qu'on
	; veut un fit bien contraint quand il n'y a pas de base.
    fc = af(n2-n1:n2+n1, n2-n1:n2+n1)
	; fc est un fltarr(2*n1+1, 2*n1+1). Le centre est fc(n1, n1).
; Calcul du niveau minimum des harmoniques pour participer a la contrainte
	; On elimine les harm dans un carre sur -+ 3 (49 elements).
    fc_min = 0.4 * (total(fc) - total(fc(n1-3:n1+3, n1-3:n1+3)))  / $
							(n_elements(fc) - 49)
; Calcul d'avant le 13 oct 2000, avec les harm intenses a cause de la base
	; On somme a part les harm de base 50m et de base 100m.
;    S_E0 = fc(n1+1, n1) + fc(n1-1, n1)
;    S_50m  = S_E0 + fc(n1, n1-1) + fc(n1, n1+1)
;    S_100m = $
;	fc(n1+2, n1  ) + fc(n1+2, n1+2) + fc(n1  , n1+2) + fc(n1-2, n1+2) + $
;	fc(n1-2, n1  ) + fc(n1-2, n1-2) + fc(n1  , n1-2) + fc(n1+2, n1-2)
;    frac = 0.3		; fraction min de la moyenne pour um harm acceptable.
;    if (S_E0 eq 0) then begin		; harm EW de 50m de E0 nuls.
;	fc_min = frac * (S_50m + S_100m) / 10
;    endif
;    if (S_E0 gt 0) then begin		; harm EW de 50m de E0 non nuls.
;	fc_min = frac * (S_50m + S_100m) / 12
;    endif

    tcon = where(fc gt fc_min)		     ; adresses des points fc > fc_min.
    tnul = where(abs(fc) lt fc_min, n_tnul)  ; sortie pour RH_FIT_CUBIC.

; Recherche des indices de ligne (y) et de colonne (x) correspondant aux 
	; indices contenus dans tcon.
    nr = 2 * n1 + 1		; nbre de lignes et colonnes du champ reduit.
    y  = tcon / nr
    x  = tcon - y * nr

    x  = x  - n1		; indices ramenes au centre du champ reduit.
    y  = y  - n1

    n_x = n_elements(x)
    n_y = n_elements(y)
    if (n_x ne n_y) then begin
	print, 'RH_FIT_QUARTIC: nbre d abcisses different du nbre d ordonnees'
	print, '	n_x, n_y :', n_x, n_y
	stop
    endif

    n2 = npx / 2

; Controle de x et y
    icon = 0
    if ((icon eq 1)and (i_stop eq 1))  then begin
	print, 'RH_FIT_QUADRIC : controle de x et y'
	window, 0
	tvscl, congrid(fc, 512, 512, cubic=-0.5)
	print, 'x =', x
	print, 'y =', y
;	window, 1
	stop
    endif
    ; conclusion: OK
; Fin de controle  

; Calcul (en double precision) des sommes du calcul des moindres carres
    x  = double(x)	&  y  = double(y)	& fc = double(fc)

    S0    = n_x

    Sx2   = total(x^2      ) 
    Sx1y1 = total(x   * y  ) 
    Sy2   = total(      y^2) 

    Sx4   = total(x^4)
    Sx3y1 = total(x^3 * y  ) 
    Sx2y2 = total(x^2 * y^2) 
    Sx1y3 = total(x   * y^3) 
    Sy4   = total(      y^4)

    Sx6   = total(x^6)
    Sx5y1 = total(x^5 * y  ) 
    Sx4y2 = total(x^4 * y^2) 
    Sx3y3 = total(x^3 * y^3) 
    Sx2y4 = total(x^2 * y^4) 
    Sx1y5 = total(x   * y^5) 
    Sy6   = total(      y^6)

    Sx8   = total(x^8)
    Sx7y1 = total(x^7 * y  ) 
    Sx6y2 = total(x^6 * y^2) 
    Sx5y3 = total(x^5 * y^3) 
    Sx4y4 = total(x^4 * y^4) 
    Sx3y5 = total(x^3 * y^5) 
    Sx2y6 = total(x^2 * y^6) 
    Sx1y7 = total(x^1 * y^7) 
    Sy8   = total(      y^8)

    Fx0   = total(fc(tcon))

    Fx2   = total(fc(tcon) * x^2    ) 
    Fxy   = total(fc(tcon) * x   * y) 
    Fy2   = total(fc(tcon) * y^2    ) 

    Fx4   = total(fc(tcon) * x^4      ) 
    Fx3y1 = total(fc(tcon) * x^3 * y  ) 
    Fx2y2 = total(fc(tcon) * x^2 * y^2) 
    Fx1y3 = total(fc(tcon) * x   * y^3) 
    Fy4   = total(fc(tcon) *       y^4) 

    mat = $
    [[S0   ,  Sx2  ,  Sx1y1,  Sy2  ,  Sx4  ,  Sx3y1,  Sx2y2,  Sx1y3,  Sy4  ], $
     [Sx2  ,  Sx4  ,  Sx3y1,  Sx2y2,  Sx6  ,  Sx5y1,  Sx4y2,  Sx3y3,  Sx2y4], $
     [Sx1y1,  Sx3y1,  Sx2y2,  Sx1y3,  Sx5y1,  Sx4y2,  Sx3y3,  Sx2y4,  Sx1y5], $
     [Sy2  ,  Sx2y2,  Sx1y3,  Sy4  ,  Sx4y2,  Sx3y3,  Sx2y4,  Sx1y5,  Sy6  ], $
     [Sx4  ,  Sx6  ,  Sx5y1,  Sx4y2,  Sx8  ,  Sx7y1,  Sx6y2,  Sx5y3,  Sx4y4], $
     [Sx3y1,  Sx5y1,  Sx4y2,  Sx3y3,  Sx7y1,  Sx6y2,  Sx5y3,  Sx4y4,  Sx3y5], $
     [Sx2y2,  Sx4y2,  Sx3y3,  Sx2y4,  Sx6y2,  Sx5y3,  Sx4y4,  Sx3y5,  Sx2y6], $
     [Sx1y3,  Sx3y3,  Sx2y4,  Sx1y5,  Sx5y3,  Sx4y4,  Sx3y5,  Sx2y6,  Sx1y7], $
     [Sy4  ,  Sx2y4,  Sx1y5,  Sy6  ,  Sx4y4,  Sx3y5,  Sx2y6,  Sx1y7,  Sy8  ]]

    vec = [Fx0,  Fx2,  Fxy,  Fy2,  Fx4,  Fx3y1,  Fx2y2,  Fx1y3,  Fy4]

    x  = float(x)   &  y  = float(y)   & fc = float(fc)

; Resolution du systeme lineaire
    if (i_sys_lin eq 1) then  resultat = CRAMER       (mat, vec)
    if (i_sys_lin eq 2) then  resultat = RH_LINEAR_LU (mat, vec, i_stop)
    if (i_sys_lin eq 3) then  resultat = RH_LINEAR_SVD(mat, vec, i_stop)
    A = resultat(0)
    B = resultat(1)
    C = resultat(2)
    D = resultat(3)
    E = resultat(4)
    F = resultat(5)
    G = resultat(6)
    H = resultat(7)
    K = resultat(8)
    
;  Construction de deux matrices, mx et my, de dimensions (2*n1+1, 2*n1+1), 
	;  comme le tableau fc defini plus haut. Le modele est calcule sur mx 
	;  et my, de dimension bien determinees, alors que le calcul du fit aux
	;  moindres carres ne se fait que sur le sous-ensemble de ce domaine
	;  ou les harmoniques ont des amplitudes suffisantes. 
	; Avant le 10 dec 99 mx et my etaient definies par rapport a ce sous-
	;  domaine, n'etaient pas necessairement de dimension 2*n1+1 ni meme
	;  carrees, alors qu'on supposait que c'etait le cas dans autocalibra-
	;  tion.pro pour l'immersion dans un tableau (np, np) ce qui produisait
	;  des erreurs.
    vx = findgen(2*n1+1) - n1
    vy = findgen(2*n1+1) - n1
	; vx et vy sont les vecteurs des colonnes et lignes (rangees par 
	;  valeurs croissantes) ou sont situes les points du champ reduit, 
	;  comptees a partir du centre du champ.

    mx = double(vx # replicate (1, n_elements(vy)))   ; nl lignes   identiques.
    my = double(replicate (1, n_elements(vx)) # vy)   ; nc colonnes identiques.

; Controle
    icon = 0
    if ((icon eq 1) and (i_stop eq 1))  then begin
	print, 'verif mx, my etc. dans fit_quartic'
	print, 'n1 =', n1
	help, mx, my
	stop
    endif

; Calcul de la fonction fit anisotrope sur tout le domaine du fit.
;   fit = A + B*mx^2 + C ij + D j2  +  E i4 +  F i3j + G i2j2 + H ij3 + K j4
    fit = A + B * mx^2  +  C * mx *my  +  D * my^2  +  E * mx^4   + $ 
	      F * mx^3 * my  +  G * mx^2 * my^2  +  H * mx *my^3  +  K * my^4
    dif = fc(tcon) - fit(tcon)
    res = sqrt ( total(dif^2) / total(fc^2) )
    c_c_q = A					; q comme quartique.

; Controle du fit et visualisation.
    icon = 0
    if ((icon eq 1) and (i_stop eq 1))  then begin
;     Visualisation de la partie de af a fitter et du fit.
	window, 0	&	wset, 0
	shade_surf, congrid(fc, 512, 512, cubic)
	window, 1	&	wset, 1
	shade_surf, congrid(fit, 512, 512, cubic=-0.5)

	if (imp0 eq 1) then begin
	    print, 'Comparaison des valeurs vraies et fittees de A et B'
	    print, '    A0 =', A0, '            B0 =', B0
	endif
	print, 'Fit anisotrope 4eme degre:'
	ch_format = "('    A =', f8.5, '   B =', f8.5, '   C =', f8.5, " + $
		"'   D =', f8.3)"
	print, format=ch_format, A, B, C, D
	ch_format = "('    E =', f8.5, '   F =', f8.5, '   G =', f8.5, " + $
		"'   H =', f8.3, '   K =', f8.3)"
	print, format=ch_format, E, F, G, H, K
	stop
    endif
    ; conclusion:
; Fin de controle  
; FIN DU CAS A DEUX DIMENSIONS

a3: J_M = 0	; fin du saut du cas a deux dimensions.

    end		; fin de RH_FIT_QUARTIC