PRO RH_HARM_N_VIS, $
	i_stop,			     $	; entree
	npi,   correl,  harm_N,	     $	; entree
	harm,  harl,    uu,    vv	; sortie


; Creation: 11 avril 2000, a partir de RH_MALC_IM_2D.

;But : construire, a partir du vecteur des correlations harm_N, la visibilite 
;	 "interferometrique", centree en milieu de tableau, et corrigee des 
;	  redondances.
;      Visibilite "interferometrique" signifie qu'il s'agit de remplir le plan
;	 uv conjugue des images interferometriques, different du plan uv con-
;	 jugue des variables de position heliographiques (ce dernier est le 
;	 "vrai" plan uv, directement rempli dans GMRT et FASR). 
;	 Dans le plan uv "interferometrique", la couverture est celle d'une
;	 grill a mailles carrees.
;
; Procedures appelantes :
;   rh_malc_im_2d,  calibration, calib_sub, calib_con,  rh_dp_calib_con

; Modifications:
; 00 avr 21	la position de l'estension NS passe a 45 au lieu de 46. NS46
;		  devient NS45.
; 01 jul 10	la notation npi de la dimension de l'image interfero est syste-
;		  matisee pour la clarte.
; 03 dec 26 : passage a 648 ou 720 harmoniques, gardant la compatibilite avec 
;		  576 harmoniques.
; 06 fev 22 : introduction de i_stop dans la liste d'entree pour arret aux
;		controles.


; Notations:
;  nbre_harm	nombre d'armoniques d'une scrutation (576 avant 20 dec 2003,
;		  648 ou 720 apres, avec lea antennes AA).
;  correl 	tableau (2, nbre_harm) indiquant les numeros des 2 antennes 
;		  correspondant a chacun des  nbre_harm  harmoniques. Permet 
;		  de faire le passage de harm_N a harm.
;  harm_N	complexarr (nbre_harm) harmoniques, rang'es au format Nancay. 
;		  Rempli en non polar ou polar juste avant l'appel a 
;		  CALC_IMAGE_HELIO.
;  npi		dimension de l'image interferometrique, figee a 128 depuis le
;		  6 jul 01, au lieu d'etre prise egale a la dimension np de 
;		  l'image heliographique np. 
;  harm		complexarr (npi, npi) tableau des harm dans le plan (u, v).

    nbre_harm = n_elements(harm_N)
; Controle de correl apres ajout des antennes AA (jan 2004)
    icon = 0
    if ( (i_stop  eq  1) and (icon eq 1) ) then begin
	    ; rappel sur ;les correlations avec les AA :
	    ;  AA1  ---- NS0 a NS17			576 a 593
	    ;  AA2  ---- ----------			594 a 611
	    ;  AA3  ---- ----------			612 a 629
	    ;  AA4  ---- ----------			630 a 647
	print, 'Harmoniques avec AA1 (576 a 593)'
	print, '    antenne de reference :'
	print, format="(10x, 18i3)", correl(0, 576:593)
	print, '    antennes de reseau :'
	print, format="(10x, 18i3)", correl(1, 576:593)
	print, ''

	print, 'Harmoniques avec AA2 (594 a 611)'
	print, '    antenne de reference :'
	print, format="(10x, 18i3)", correl(0, 594:611)
	print, '    antennes de reseau :'
	print, format="(10x, 18i3)", correl(1, 594:611)
	print, ''

	print, 'Harmoniques avec AA3 (612 a 629)'
	print, '    antenne de reference :'
	print, format="(10x, 18i3)", correl(0, 612:629)
	print, '    antennes de reseau :'
	print, format="(10x, 18i3)", correl(1, 612:629)
	print, ''

	print, 'Harmoniques avec AA4 (630 a 647)'
	print, '    antenne de reference :'
	print, format="(10x, 18i3)", correl(0, 630:647)
	print, '    antennes de reseau :'
	print, format="(10x, 18i3)", correl(1, 630:647)
	print, ''

	stop
    endif

    harm   = complexarr (npi, npi)	; tableau des harm dans le plan (u, v).
    harl   = complexarr (npi, npi)	; spectre du lobe theorique

; Tableaux des positions des antennes le long des axes des reseaux, en unite 
	;  des pas des reseaux (49,903m en EW et 54.274m en NS)
	; Systeme de coordonnees:
	; - origine en NS0,
	; - axes diriges vers W et N. 
	; Avec ces conventions les variables de position interferometriques
	; 	Wew.u  et  Wns.u 
	;		avec: u		vecteur unitaire vers la source
	;		      Wew	vecteur unitaire des bases EW
	;		      Wns	-------------------------- NS
	;   qui apparaissent dans l'expression du dephasage comme les quantites
	;   conjuguees par TF des bases bew et bns, sont croissantes vers W et 
	;   N. On obtient donc une image du soleil bien orientee directement 
	;   par TF. Avec le systeme (W, S) utilise precedemment, on obtenait 
	;   une image dans les axes (W, S).
	; Les numeros des antennes sont:
	; 0 ext2, 1 ext1, 2 ext0, 3 H1, ..., 18 H16, 19 NS0 ..., 43 NS24.
    xant = [-48, -16, -15,			   $	; Ext 2, 1, 0
	    -14, -12, -10, -8, -6,- 4, -2,  0,     $	; H 1 a 8 (H8 = NS0)
	      2,   4,   6,  8, 10, 12, 14, 16,     $   	; H 9 a 16 (19 elem)
	  0,  0,   0,   0,  0,  0,  0,  0,  0,  0, $	; NS 0 a 9.
	  0,  0,   0,   0,  0,  0,  0,  0,  0,  0, $	; NS 10 a 19
	  0,  0,   0,   0,  0,			   $	; NS 20 a 23 et NS 45.
	 -1, -3,  -5,  -7]				; AA1 a AA4
    yant = [  0,   0,   0,			   $	; Ext 2, 1, 0
	      0,   0,   0,  0,  0,- 0,  0,  0,     $	; H 1 a 8
	      0,   0,   0,  0,  0,  0,  0,  0,     $   	; H 9 a 16 (19 elem)
	  0, -1,  -2,  -3, -4, -5, -6, -7, -8, -9, $	; NS 0 a 9.
	-10,-11, -12, -13,-14,-15,-16,-17,-18,-19, $	; NS 10 a 19
	-20,-21, -22, -23,-45,			   $	; NS 20 a 23 et NS 45.
	 -8, -8,  -8,  -8]				; AA1 a AA4

; Definition des projections EW et NS des bases (en unites de pas des reseaux).
	; La valeur d'un harmonique est:   A exp (i phi) avec
	;	A	amplitude
	;	phi	dephasage de la 2eme antenne (omega*t + phi) par
	;		  rapport a l'antenne de reference (omega*t).
	; Pour les correlations 2D ce sont les antennes NS qui sont considerees
	;  comme les antennes de references (confirmation P. Picard 20 mai 99).
	; Rangement dans le tableau des harmoniques format Nancay:
	;				correlations
	;  NS0  avec E2, E1, H1 a H16	  0 a  17
	;  NS1  ---- ----------------    18 a  35
	;  NS23 ---- ----------------       a 431
	;  NS45	---- ---------------- 	432 a 449

	; jusqu'au 7 oct 98 inclus:
	;  E0	avec NS0  a NS17	450 a 467
	;  --   ---- NS10 a NS23	468 a 481
	;  --	---- NS45		482
	;  --	---- NS7  a NS9		483 a 485
	; a partir du 8 oct 98 inclus:
	;  NS45	avec NS0  a NS17	450 a 467
	;  ---- ---- NS10 a NS23	468 a 481
	;  ----	---- NS45               482
	;  ---- ---- NS7  a NS9         483 a 485

	;  E2	---- E2, E1, H1 a H16	486 a 503
	;  E1	---- E2, E1, H1 a H16	504 a 521
	;  E0	---- E2, E1, H1 a H16	522 a 539
	;  NS8	---- NS0  a NS17	540 a 557
	;  NS0	---- NS10 a NS23, NS45	558 a 572
	;  ---	---- NS7 a NS9		573 a 575
	;
	;  AA1  ---- NS0 a NS17		576 a 593
	;  AA2  ---- ----------		594 a 611
	;  AA3  ---- ----------		612 a 629
	;  AA4  ---- ----------		630 a 647

; Controle du niveau d'harmoniques polar :
	; NS0  avec E2  a H16	  0   17
	; NS45 ---- ---------	432  449
	; ---- ---- les NS	450  485
	; NS8  ---- ------	540  557
	; NS0  ---- ------	558  575

    icon = 0
    if ( (i_stop  eq  1) and (icon eq 1) )  then begin
	toto = [harm_N(  0 :  17),  harm_N(432 : 449),  harm_N(450 : 485), $
		harm_N(540 : 557),  harm_N(558 : 575)]
	window, 0
	plot, abs(toto), xstyle=1
	xyouts, 0.5, 0.97, /normal, alignment=0.5, 'abs(toto)'
	print, 'abs(toto) ='
	print, abs(toto)
	stop
    endif

; Controle repris de RH_CALIB_CON 25 sep 03

; Controle des harmoniques NS de NS0_ew et NS0_ns (redondance polar ?)
	; fait le 10 avril 03 : la non correction de niveau des harmoniques NS
	;   pour la rotation et le depointage laissait supposer un probleme
	;   du cote du traitement de la redondance.
    icon = 0
    if ( (i_stop  eq  1) and (icon eq 1) )  then begin
	h_NS0_ew = complexarr(24)
	h_NS0_ns = complexarr(24)
	for i=1, 23 do  h_NS0_ew(i) = harm_N(9 + 18 *i)
	h_NS0_ns( 7) = harm_N(573 : 575)
	h_NS0_ns(10) = harm_N(558 : 571)
	a_h_NS0_ew = abs(h_NS0_ew)
	a_h_NS0_ns = abs(h_NS0_ns)
;     Traces
	amax = max(a_h_NS0_ew) > max(a_h_NS0_ns)
	amin = min(a_h_NS0_ew) < min(a_h_NS0_ns)
	da = amax - amin
	y1 = amin - 0.05 * da		& y2 = amax + 0.05 * da
	window, 1
	loadct, 0
	plot,  a_h_NS0_ew, xstyle=1, yrange=[y1, y2], ystyle=1
	oplot, a_h_NS0_ns, linestyle=1
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
	    'abs(h_NS0_ew) ___,  abs(h_NS0_ns) ....'
	stop
    endif


    bew =   reform(xant(correl(1, *)) - xant(correl(0, *)))
    bns =   reform(yant(correl(1, *)) - yant(correl(0, *)))
	; bew et bns sont des intarr(nbre_harm). Ce sont des bases normalisees,
	;   (comptees en unites de pas des reseaux sur l'axe des reseaux), 
	;   orientees de l'antenne de reference vers l'antenne de reseau : 
	;   pour les harmoniques "obliques" bns est donc toujours dirige vers 
	;   le nord et >0.
	; Remarque: 
	;  - correl(0, *) est le numero d'antenne de ref (en debut de liste 19 
	;      pour NS0)
	;  - correl(1, *) -------------------------- res (-- --------------  0
	;      a 18 pour E2 a H16)
	; Le vecteur de la base est oriente de l'antenne de reference vers 
	;   l'antenne de reseau (oppose a la version de J-M).
	; Avec cette convention on a:
	;  	phi = 2 pi (bew dew Wew.u  +  bns dns Wns.u)
	;	ou dew et dns sont les pas normalises et Wew et Wns definis 
	;	  plus haut (vecteurs unitaires des bases EW et NS).
	; Rem  : changer bew et bns en -bew et -bns symetrise l'image par rap-
	;        port a son centre (en coordonnees interferometriques). Meme 
	;	 effet si on change le tableau des harmoniques "harm" en son 
	;	 complexe conjugue. C'est li'e au role de l'antenne de referen-
	;	 ce (voir plus haut).

; Controle des bases avec les AA
    icon = 0
    if ( (i_stop  eq  1) and (icon eq 1) ) then begin
	;  AA1  ---- NS0 a NS17		576 a 593
	;  AA2  ---- ----------		594 a 611
	;  AA3  ---- ----------		612 a 629
	;  AA4  ---- ----------		630 a 647
	bew_red = bew(576:647)		& bns_red = bns(576:647)
	window, 0
	plot, bew_red, bns_red, psym=2	; 2 *, 3 ., 4 losange
	xyouts, 0.5, 0.97, /normal, alignment=0.5, 'bases AA3'
	stop
    endif

; Verifications du rangement des harmoniques. Conclusion: rangement OK.
    icon = 0
    if ( (i_stop  eq  1) and (icon eq 1) ) then begin
	cew = reform(bew, nbre_harm)	; reform retire la dimension degeneree.
	cns = reform(bns, nbre_harm)
	nmin = 0
	nmax = nbre_harm - 1
	plot, cew(nmin:nmax), cns(nmin:nmax), psym=3	; 1 +, 2 *, 3 .,4 diam
	correl0 = reform (correl(0, *))
	correl1 = reform (correl(1, *))
	for i = 0, 100  do begin
;	    print, 'correl: i, correl0, correl1:', i, correl0(i), correl1(i)
	endfor
	stop
    endif

;  Controle des harm NS avec NS0_ew
    icon = 0
    if ( (i_stop  eq  1) and (icon eq 1) ) then begin
	harm_ns = complexarr(25)
	for j = 1, 24 do harm_ns(j) = harm_N(9 + 18*j)
	nz = 24		; zoom de 0 a nz. NUMERO D'ANTENNE ET NON D'HARMONIQUE
	window, 0
	plot, abs(harm_ns(0:nz))
	xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'abs(harm avec NS0_ew)'
	stop
    endif

; Remplissage du tableau des harmoniques a 2 dimensions (dans le plan uv con-
	;   jugue des variables de position interferometriques)
	; On ne considere que les harmoniques qui ne sont pas strictement nuls.
	;   On evite ainsi de comptabiliser les harmoniques mis a zero par les
	;   choix faits dans RH_DPNEW pour supprimer certaines antennes ou 
	;   eviter les redondances mediocres. Pour ces derniers cas les ampli-
	;   tudes ne sont pas artificiellement reduites.
	; Si aucun harmonique n'est nul ou mis a zero, tab contient les entiers
	;   de 0 a  nbre_harm - 1.
    tab = where(abs(harm_N) ne 0., c)
    if (c gt 0) then begin	; precaution, c=0 correspond a des images vides
	uu = bew (tab)
	vv = bns (tab)
	    ; rappel : bew et bns sont des bases normalisees, comptees en uni-
	    ;		tes de pas des reseaux, sur l'axe des reseaux. 
 	    ; uu et vv sont proportionnels aux freq spatiale EW et NS. Ils peu-
	    ;   etre <0 et ne peuvent servir a adresser le tableau "harm" des 
	    ;   harmoniques spatiaux. On adresse harm par up = npi/2 + uu et 
	    ;   vp = npi/2 + vv. 
;     Remplissage du plan (u,v) au points (uu, vv), dans 1/2 plan seulement
	    ; Le nbre de pts npi etant pair, on ne peut prendre l'origine au 
	    ;   centre du tableau. On la prend arbitairement en (npi/2, npi/2).
	    ; Voir commentaire a l'appel de RH_HARM_N_VIS dans MALC_IM_2D.
	up = npi/2 + uu		; abscisse p r au coin inf gauche.
	vp = npi/2 + vv		; ordonnee p r au coin inf gauche.
;     Ancien remplissage (delouisien, c'est a dire faux)
	    ; (en commentaires pour ne pas cumuler avec remplissage correc).
;	harm(up, vp) = harm(up, vp) + harm_N(tab)
	    ; Faute trouvee le 25 sept 03 : uu et vv peuvent prendre plusieurs
	    ;   fois les memes valeurs a cause des redondances. Il faut cumuler
	    ;   et non ecraser comme le fait la sequence ci dessus. 
	    ;   Cela explique que des harmoniques redondants se retrouvaient
	    ;   nuls quand on mettait a zero leur derniere determination dans
	    ;   harm_N. 
	    ; C'etait le dernier heritage delouisien, qui n'a cede qu'a un
	    ;   examen detaill'e de cas polar avec RH_CALIB_CON : les harmoni-
	    ;   ques NS avec NS0_ew de 1 a 7 du Cygne avec NS0 tournee deve-
	    ;	naient nuls quand on mettait a zero les harm de NS8 !!
;     Remplissage correct aux points (uu, vv)
	n_uu = n_elements(uu)
	for j = 0,  n_uu - 1   do begin		; boucle sur les harm non nuls.
	    if (abs(uu(j))  lt  64) then $		; eviter l'harm EW +64
		harm (up(j), vp(j)) = harm (up(j), vp(j)) + harm_N(tab(j))
	endfor
	harm1 = harm		; sauvegarde sans sym hermittique.

;     Complement par symetrie hermittique aux points (-uu, -vv) 
	un = npi/2 - uu
	vn = npi/2 - vv
;     Ancien remplissage (delouisien, donc faux)
;	harm(un, vn) = harm(un, vn) + conj(harm_N(tab))
;     Remplissage correct
	n_uu = n_elements(uu)
	for j = 0, n_uu - 1   do begin		; boucle sur les harm non nuls.
	    if (abs(uu(j))  lt  64)  then $		; eviter l'harm EW +64
	      harm (un(j), vn(j)) = harm (un(j), vn(j)) + conj(harm_N(tab(j)) )
	endfor
	harm_1 = harm	; sauvegarde symetrie hermittique avec redondances.

;     Controle: comparaison de harm avant et apres symetrie hermittique
	    ; le controle de harl est plus bas.
	icon = 0
	if ( (i_stop  eq  1) and (icon eq 1) ) then begin
	    nz = 16			; zooming de -nz a nz - 1
	    i_sh_tv = 2			; 1 shade_surf, 2 tvscl
	    n1 = npi/2 - nz  & n2 = npi/2 + nz - 1
	    harm_red  = harm (n1:n2, n1:n2)
	    harm1_red = harm1(n1:n2, n1:n2)
	    window, 0, xsize=512, ysize=512
	    if (i_sh_tv eq 1) then begin
		loadct, 0
		shade_surf, congrid(abs(harm1_red), 512, 512)
	    endif
	    if (i_sh_tv  eq  2) then begin
		loadct, 13
		tvscl, congrid(abs(harm1_red), 512, 512)
	    endif
	    loadct, 0
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'harm avant sym hermittique et avant corr redondances'
	    window, 1, xsize=512, ysize=512
	    if (i_sh_tv  eq  1) then begin
		loadct, 0
		shade_surf, congrid(abs(harm_red), 512, 512)
	    endif
	    if (i_sh_tv  eq  2) then begin
		loadct, 13
		tvscl, congrid(abs(harm_red) , 512, 512)
	    endif
	    loadct, 0
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'harm apres sym hermittique et avant corr redondances'
	    stop
	endif
;     Fin de controle

;     Construction de la repartition des harm pour un lobe theorique et compor-
	  ; tant la meme redondance que pour les harm mesures.
;     Remplissage delouisien (donc faux), en commentaire pour ne pas cumuler)
;	harl(up, vp) = harl(up, vp) + 1.
;	harl(un, vn) = harl(un, vn) + 1.
;     Remplissage correct
	for j=0, n_uu - 1 do begin		; boucle sur les harm non nuls.
	    if(abs(uu(j)) lt 64) then begin		; eviter l'harm EW +64
		harl(up(j), vp(j)) = harl(up(j), vp(j)) + 1
		harl(un(j), vn(j)) = harl(un(j), vn(j)) + 1
	    endif
	endfor

;     Controle 2D de harl (visualisation directe de la redondance en 2D)
	    ; Verifie correct le 26 sept 03, apres une nuit d'efforts.
	icon = 0
	if ( (i_stop  eq  1) and (icon eq 1) ) then begin
	    nz = 18			; zooming de -nz a nz - 1
	    i_sh_tv = 2			; 1 shade_surf, 2 tvscl
	    n1 = npi/2 - nz   & n2 = npi/2  + nz - 1
	    harl_red  = harl (n1:n2, n1:n2)
	    harl_red(nz, nz) = 3		; remplissage origine
	    if (i_sh_tv eq 1) then begin
		loadct, 0
		window, 1
		shade_surf, congrid(abs(harl_red), 512, 512)
	    endif
	    if (i_sh_tv eq 2) then begin
		loadct, 13
		window, 1, xsize=512, ysize=512
		tvscl, congrid(abs(harl_red), 512, 512)
	    endif
	    loadct, 0
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'TF du lobe theorique redondant avec sym hermittique'
	    stop
	endif
;     Fin de controle

;     Controle de la redondance sur les axes u et v (25 sep 03)
	    ; Verifie correct le 26 sept 03, apres une nuit d'efforts.
	icon = 0
	if ( (i_stop  eq  1) and (icon eq 1) ) then begin
	    harl_u = harl(npi/2 : npi-1, npi/2)
	    window, 1
	    plot, harl_u, yrange=[0, 1.1*max(harl_u)], ystyle=1, $
			xrange=[-1, 20], xstyle=1
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'Redondance sur axe u'

	    harl_v = harl(npi/2, npi/2 : npi-1)
	    window, 2
	    plot, harl_v, yrange=[0, 1.1*max(harl_v)], ystyle=1, $
			xrange=[-3, 20], xstyle=1
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'Redondance sur axe v'
	    stop
	endif

;     Compensation de la redondance de certains harmoniques.
	tab_h       = where (abs(harl) gt 0.)
	harm(tab_h) = harm(tab_h) / abs(harl(tab_h))
	harl_1 = harl		; sauvegarde avec redondances.
	harl(tab_h) = 1.

;     Controle de la correction de redondance (visualisation 2D)
	; fait le 10 avril 03 : la non correction de niveau des harmoniques NS
	;   pour la rotation et le depointage laissait supposer un probleme
	;   du cote du traitement de la redondance.
	icon = 0
	if ( (i_stop  eq  1) and ( icon eq 1) ) then begin
;	  Choix de trace
	    i_sh_tv = 2		; 1 shade_surf,   2 tvscl.
	    i_harm_harl = 1	; 1 visu "visibilite, 2 de TF du lobe
	    A = 0.01		; compression de dynamique y log(1 + A*x/xmax)
				;   lineaire : prendre A = 0.01
;	  Traces
		; rappel : les "_1" sont les visibilite et TF de lobe comple-
		;	tee par symetrie hermittique et avec redondances.
	    harl_512   = congrid(abs(harl)  , 512, 512)
	    harm_512   = congrid(abs(harm)  , 512, 512)
	    harm_1_512 = congrid(abs(harm_1), 512, 512)
	    harl_1_512 = congrid(abs(harl_1), 512, 512)
	    diff = abs(harm_1_512 - harm_512)
	    if (i_harm_harl  eq  1) then begin
		toto   = harm_512
		toto_1 = harm_1_512
	    endif
	    if (i_harm_harl  eq  2) then  begin
		toto   = harl_512
		toto_1 = harl_512
	    endif
	    toto   = alog(1 + A * toto   / max(toto  ))
	    toto_1 = alog(1 + A * toto_1 / max(toto_1))
;	  Remplissage avec redondances
	    if (i_sh_tv  eq  1) then loadct, 0
	    if (i_sh_tv  eq  2) then loadct, 13
	    if (i_sh_tv  eq  1) then begin
		window, 0
		shade_surf, toto_1
	    endif
	    if (i_sh_tv  eq  2) then begin
		window, 0, xsize=512, ysize=512
		tvscl, toto_1
	    endif
	    loadct, 0
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'abs(remplissage avec redondance)'
;	  Remplissage apres correction de redondance
	    if (i_sh_tv  eq  1) then loadct, 0
	    if (i_sh_tv  eq  2) then loadct, 13
	    if (i_sh_tv  eq  1) then begin
		window, 1
		shade_surf, toto
	    endif
	    if (i_sh_tv  eq  2) then begin
		window, 1, xsize=512, ysize=512
		tvscl, toto
	    endif
	    loadct, 0
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'abs(remplissage apres correction de redondance)'
;	  Difference des remplissage avsc et sans redondance
;	    window, 2
;	    shade_surf, diff
	    stop
	endif
	; la correction est tres visible sur les harm NS purs.
;     Fin de controle

;     Controle de la correction de redondance (sur axe NS seul) 
	; fait le 25 sept 03. Verifi'e correct le 26 sep 03.
	icon = 0
	if ( (i_stop  eq  1) and (icon eq 1) ) then begin
	    harm1_ns  = harm1 (npi/2,  npi/2 : npi - 1)	; avec redond sans sym
							;   hermittique
	    harm_1_ns = harm_1(npi/2,  npi/2 : npi - 1)	; avec redondance
	    harm_ns   = harm  (npi/2,  npi/2 : npi - 1)	; sans redondance
	    nz = 30			; zoom de 0 a nz
;	  Trace avec redondance sans symetrie hermittique
	    window, 0
	    plot, abs(harm1_ns(0:nz))
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'axe V, freq > 0 : abs(visib avec redondance sans sym hermit)'
;	  Trace avec redondance
	    window, 1
	    plot, abs(harm_1_ns(0:nz))
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'axe V, freq v > 0 : abs(visib avec redondance)'
;	  Remplissage apres correction de redondance
	    window, 2
	    plot, abs(harm_ns(0:nz))
	    xyouts, 0.5, 0.97, /normal, alignment=0.5, charsize=1.3, $
		'axe V freq > 0 : abs(visib apres correction de redondance)'
	    stop
	endif
	; la correction est tres visible sur les harm NS purs.
;     Fin de controle

    endif		; fin du if "images non nulles".

    end		; fin de RH_HARM_N_VIS.

