;+ ***********************************************************************
; NAME:
;	TIME_IND_NRH
;
; PURPOSE:
;	Cette fonction determine le numero de la ligne contenant les donnees
; correspondant a une heure donnee dans un fichier NRH 
;
; CATEGORY:
;	Traitement de fichiers NRH
;
; CALLING SEQUENCE:
;	 IND = TIME_IND_NRH, fichier, heure
;
; INPUTS:
;	FICHIER		Nom du fichier
;	HEURE		Heure recherchee (chaine ASCII)
;
; OUTPUTS:
;	IND		Numero de la ligne
;	HEURE		Retourne l'heure lue
;
; PROCEDURE:
;	Cette fonction lit les heures successives contenues dans la colonne
; TIME des fichiers NRH, jusqu'a trouver l'intervalle d'heure recherchee
;	Si l'heure cherchee n'est pas dans le fichier, un message d'erreur
; est envoye et le numero de la ligne retourne = 0
;
; EXAMPLE:
;	IND= TIME_IND_NRH( Str_fic.file, Str_visu.Hdem)
;
; MODIFICATION HISTORY:
;	Ecrit par: J Bonmartin le 12/01/98
;	Le 03/11/98 Enleve HOURGLASS (JB)
;-*******************************************************************
FUNCTION TIME_IND_NRH, fichier, heure

	H= HEADFITS(Fichier)
	IF FXPAR(h, 'EXTEND') EQ 0 THEN BEGIN 
			r=WIDGET_MESSAGE('TIME out of range')
                      Return, 0                 ;Fichier base de donnee
                      END

      temps = HMS(heure)

	FXBOPEN,UNIT, fichier, 1, h
	Npt= FXPAR( h, 'NAXIS2')
	ind = 1
	FXBREAD,Unit, Time, 'TIME', Ind
      WHILE time lt temps DO Begin
                      ind = ind+1
             if IND gt Npt THEN BEGIN
			r=WIDGET_MESSAGE('TIME out of range')
                      Return, 0                 ;Fin de fichier
                      END
		FXBREAD,Unit, Time, 'TIME', Ind
	END

	FXBCLOSE, Unit
	Heure = MSH (Time)

	Return, IND - 1



END